! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.1_rs5 symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Mon Oct 19 13:08:06 2015
! Working directory    : /home/mpayer/KPP
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
        ! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
          X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
        END DO
      END DO

      DO i=NVAR, 1, -1
        ! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
          X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
        END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
        ! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
          X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
        END DO
      END DO

      DO i=NVAR, 1, -1
        ! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
          X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
        END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
        ! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
          XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
          XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
        END DO
      END DO

      DO i=NVAR, 1, -1
        ! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
          XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
          XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
        END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!              X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!              sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!         !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!              X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!       END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!         !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!              X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!       END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(75) = X(75)-JVS(234)*X(59)
  X(92) = X(92)-JVS(327)*X(91)
  X(98) = X(98)-JVS(362)*X(39)-JVS(363)*X(87)
  X(99) = X(99)-JVS(369)*X(40)
  X(100) = X(100)-JVS(376)*X(93)
  X(106) = X(106)-JVS(424)*X(97)
  X(110) = X(110)-JVS(457)*X(75)
  X(115) = X(115)-JVS(495)*X(83)
  X(117) = X(117)-JVS(514)*X(114)
  X(119) = X(119)-JVS(526)*X(81)-JVS(527)*X(107)
  X(120) = X(120)-JVS(538)*X(60)-JVS(539)*X(69)
  X(121) = X(121)-JVS(549)*X(74)
  X(122) = X(122)-JVS(557)*X(98)-JVS(558)*X(102)-JVS(559)*X(111)-JVS(560)*X(118)
  X(123) = X(123)-JVS(573)*X(117)
  X(125) = X(125)-JVS(589)*X(61)
  X(126) = X(126)-JVS(600)*X(97)
  X(127) = X(127)-JVS(610)*X(84)-JVS(611)*X(117)
  X(128) = X(128)-JVS(621)*X(104)-JVS(622)*X(105)-JVS(623)*X(109)-JVS(624)*X(112)-JVS(625)*X(113)-JVS(626)*X(114)&
             &-JVS(627)*X(116)-JVS(628)*X(117)
  X(131) = X(131)-JVS(658)*X(83)-JVS(659)*X(117)
  X(132) = X(132)-JVS(669)*X(88)
  X(133) = X(133)-JVS(678)*X(90)-JVS(679)*X(114)
  X(134) = X(134)-JVS(689)*X(70)-JVS(690)*X(89)
  X(136) = X(136)-JVS(712)*X(37)-JVS(713)*X(79)-JVS(714)*X(129)
  X(137) = X(137)-JVS(727)*X(90)-JVS(728)*X(91)-JVS(729)*X(98)-JVS(730)*X(102)-JVS(731)*X(106)-JVS(732)*X(109)-JVS(733)&
             &*X(124)-JVS(734)*X(133)
  X(138) = X(138)-JVS(753)*X(91)
  X(139) = X(139)-JVS(761)*X(61)-JVS(762)*X(69)
  X(141) = X(141)-JVS(781)*X(96)-JVS(782)*X(130)
  X(142) = X(142)-JVS(794)*X(59)-JVS(795)*X(63)-JVS(796)*X(64)-JVS(797)*X(94)-JVS(798)*X(110)-JVS(799)*X(140)
  X(143) = X(143)-JVS(814)*X(86)-JVS(815)*X(125)-JVS(816)*X(135)-JVS(817)*X(139)
  X(145) = X(145)-JVS(837)*X(54)-JVS(838)*X(62)-JVS(839)*X(89)-JVS(840)*X(94)-JVS(841)*X(100)-JVS(842)*X(102)-JVS(843)&
             &*X(107)-JVS(844)*X(121)-JVS(845)*X(122)-JVS(846)*X(137)-JVS(847)*X(138)-JVS(848)*X(140)-JVS(849)*X(144)
  X(146) = X(146)-JVS(882)*X(114)
  X(147) = X(147)-JVS(891)*X(74)-JVS(892)*X(103)-JVS(893)*X(129)-JVS(894)*X(144)
  X(148) = X(148)-JVS(906)*X(87)-JVS(907)*X(114)
  X(149) = X(149)-JVS(916)*X(84)-JVS(917)*X(88)-JVS(918)*X(91)-JVS(919)*X(92)-JVS(920)*X(98)-JVS(921)*X(99)-JVS(922)&
             &*X(102)-JVS(923)*X(103)-JVS(924)*X(109)-JVS(925)*X(121)-JVS(926)*X(124)-JVS(927)*X(126)-JVS(928)*X(127)&
             &-JVS(929)*X(129)-JVS(930)*X(132)-JVS(931)*X(138)-JVS(932)*X(143)-JVS(933)*X(144)-JVS(934)*X(146)-JVS(935)&
             &*X(147)-JVS(936)*X(148)
  X(150) = X(150)-JVS(958)*X(95)-JVS(959)*X(111)-JVS(960)*X(114)-JVS(961)*X(118)-JVS(962)*X(144)
  X(151) = X(151)-JVS(971)*X(87)-JVS(972)*X(97)-JVS(973)*X(124)-JVS(974)*X(148)-JVS(975)*X(150)
  X(152) = X(152)-JVS(984)*X(86)-JVS(985)*X(90)-JVS(986)*X(91)-JVS(987)*X(98)-JVS(988)*X(99)-JVS(989)*X(102)-JVS(990)&
             &*X(106)-JVS(991)*X(113)-JVS(992)*X(115)-JVS(993)*X(116)-JVS(994)*X(124)-JVS(995)*X(126)-JVS(996)*X(130)&
             &-JVS(997)*X(131)-JVS(998)*X(132)-JVS(999)*X(133)-JVS(1000)*X(135)-JVS(1001)*X(138)-JVS(1002)*X(143)-JVS(1003)&
             &*X(146)-JVS(1004)*X(148)-JVS(1005)*X(149)-JVS(1006)*X(150)-JVS(1007)*X(151)
  X(153) = X(153)-JVS(1027)*X(96)-JVS(1028)*X(97)-JVS(1029)*X(130)-JVS(1030)*X(148)
  X(154) = X(154)-JVS(1041)*X(96)-JVS(1042)*X(124)-JVS(1043)*X(130)-JVS(1044)*X(148)-JVS(1045)*X(150)-JVS(1046)*X(153)
  X(155) = X(155)-JVS(1056)*X(54)-JVS(1057)*X(85)-JVS(1058)*X(100)-JVS(1059)*X(102)-JVS(1060)*X(138)-JVS(1061)*X(141)&
             &-JVS(1062)*X(148)-JVS(1063)*X(151)-JVS(1064)*X(153)-JVS(1065)*X(154)
  X(156) = X(156)-JVS(1076)*X(95)-JVS(1077)*X(111)-JVS(1078)*X(118)-JVS(1079)*X(129)-JVS(1080)*X(130)-JVS(1081)*X(135)&
             &-JVS(1082)*X(141)-JVS(1083)*X(143)-JVS(1084)*X(144)-JVS(1085)*X(150)-JVS(1086)*X(153)-JVS(1087)*X(154)&
             &-JVS(1088)*X(155)
  X(157) = X(157)-JVS(1101)*X(60)-JVS(1102)*X(83)-JVS(1103)*X(85)-JVS(1104)*X(95)-JVS(1105)*X(96)-JVS(1106)*X(100)&
             &-JVS(1107)*X(101)-JVS(1108)*X(102)-JVS(1109)*X(111)-JVS(1110)*X(118)-JVS(1111)*X(120)-JVS(1112)*X(121)&
             &-JVS(1113)*X(127)-JVS(1114)*X(130)-JVS(1115)*X(131)-JVS(1116)*X(132)-JVS(1117)*X(133)-JVS(1118)*X(135)&
             &-JVS(1119)*X(138)-JVS(1120)*X(139)-JVS(1121)*X(141)-JVS(1122)*X(144)-JVS(1123)*X(146)-JVS(1124)*X(147)&
             &-JVS(1125)*X(148)-JVS(1126)*X(150)-JVS(1127)*X(151)-JVS(1128)*X(153)-JVS(1129)*X(154)-JVS(1130)*X(155)&
             &-JVS(1131)*X(156)
  X(158) = X(158)-JVS(1147)*X(47)-JVS(1148)*X(48)-JVS(1149)*X(50)-JVS(1150)*X(56)-JVS(1151)*X(57)-JVS(1152)*X(72)&
             &-JVS(1153)*X(107)-JVS(1154)*X(119)
  X(159) = X(159)-JVS(1169)*X(87)-JVS(1170)*X(104)-JVS(1171)*X(114)-JVS(1172)*X(148)-JVS(1173)*X(150)
  X(160) = X(160)-JVS(1185)*X(90)-JVS(1186)*X(92)-JVS(1187)*X(93)-JVS(1188)*X(95)-JVS(1189)*X(111)-JVS(1190)*X(118)&
             &-JVS(1191)*X(121)-JVS(1192)*X(132)-JVS(1193)*X(133)-JVS(1194)*X(135)-JVS(1195)*X(138)-JVS(1196)*X(143)&
             &-JVS(1197)*X(144)-JVS(1198)*X(146)-JVS(1199)*X(147)-JVS(1200)*X(148)-JVS(1201)*X(150)-JVS(1202)*X(151)&
             &-JVS(1203)*X(154)-JVS(1204)*X(155)-JVS(1205)*X(156)-JVS(1206)*X(159)
  X(161) = X(161)-JVS(1220)*X(87)-JVS(1221)*X(114)-JVS(1222)*X(146)-JVS(1223)*X(148)-JVS(1224)*X(150)
  X(162) = X(162)-JVS(1236)*X(70)-JVS(1237)*X(79)-JVS(1238)*X(84)-JVS(1239)*X(105)-JVS(1240)*X(117)-JVS(1241)*X(127)&
             &-JVS(1242)*X(129)-JVS(1243)*X(131)-JVS(1244)*X(134)-JVS(1245)*X(135)-JVS(1246)*X(136)-JVS(1247)*X(141)&
             &-JVS(1248)*X(144)-JVS(1249)*X(150)-JVS(1250)*X(153)-JVS(1251)*X(154)-JVS(1252)*X(155)-JVS(1253)*X(156)&
             &-JVS(1254)*X(157)-JVS(1255)*X(159)-JVS(1256)*X(160)-JVS(1257)*X(161)
  X(163) = X(163)-JVS(1270)*X(52)-JVS(1271)*X(62)-JVS(1272)*X(80)-JVS(1273)*X(104)-JVS(1274)*X(105)-JVS(1275)*X(109)&
             &-JVS(1276)*X(112)-JVS(1277)*X(113)-JVS(1278)*X(114)-JVS(1279)*X(116)-JVS(1280)*X(117)-JVS(1281)*X(146)&
             &-JVS(1282)*X(151)-JVS(1283)*X(159)-JVS(1284)*X(161)
  X(164) = X(164)-JVS(1296)*X(51)-JVS(1297)*X(55)-JVS(1298)*X(74)-JVS(1299)*X(86)-JVS(1300)*X(90)-JVS(1301)*X(103)&
             &-JVS(1302)*X(106)-JVS(1303)*X(114)-JVS(1304)*X(116)-JVS(1305)*X(120)-JVS(1306)*X(121)-JVS(1307)*X(125)&
             &-JVS(1308)*X(127)-JVS(1309)*X(129)-JVS(1310)*X(130)-JVS(1311)*X(131)-JVS(1312)*X(132)-JVS(1313)*X(133)&
             &-JVS(1314)*X(134)-JVS(1315)*X(135)-JVS(1316)*X(136)-JVS(1317)*X(138)-JVS(1318)*X(139)-JVS(1319)*X(141)&
             &-JVS(1320)*X(143)-JVS(1321)*X(144)-JVS(1322)*X(146)-JVS(1323)*X(147)-JVS(1324)*X(148)-JVS(1325)*X(149)&
             &-JVS(1326)*X(150)-JVS(1327)*X(151)-JVS(1328)*X(152)-JVS(1329)*X(153)-JVS(1330)*X(154)-JVS(1331)*X(155)&
             &-JVS(1332)*X(156)-JVS(1333)*X(157)-JVS(1334)*X(159)-JVS(1335)*X(160)-JVS(1336)*X(161)-JVS(1337)*X(162)&
             &-JVS(1338)*X(163)
  X(165) = X(165)-JVS(1350)*X(58)-JVS(1351)*X(62)-JVS(1352)*X(74)-JVS(1353)*X(76)-JVS(1354)*X(82)-JVS(1355)*X(84)&
             &-JVS(1356)*X(86)-JVS(1357)*X(87)-JVS(1358)*X(88)-JVS(1359)*X(90)-JVS(1360)*X(97)-JVS(1361)*X(98)-JVS(1362)&
             &*X(99)-JVS(1363)*X(103)-JVS(1364)*X(106)-JVS(1365)*X(111)-JVS(1366)*X(112)-JVS(1367)*X(114)-JVS(1368)*X(115)&
             &-JVS(1369)*X(117)-JVS(1370)*X(118)-JVS(1371)*X(120)-JVS(1372)*X(121)-JVS(1373)*X(122)-JVS(1374)*X(123)&
             &-JVS(1375)*X(124)-JVS(1376)*X(126)-JVS(1377)*X(127)-JVS(1378)*X(129)-JVS(1379)*X(130)-JVS(1380)*X(131)&
             &-JVS(1381)*X(132)-JVS(1382)*X(133)-JVS(1383)*X(134)-JVS(1384)*X(135)-JVS(1385)*X(136)-JVS(1386)*X(137)&
             &-JVS(1387)*X(138)-JVS(1388)*X(139)-JVS(1389)*X(141)-JVS(1390)*X(143)-JVS(1391)*X(144)-JVS(1392)*X(146)&
             &-JVS(1393)*X(147)-JVS(1394)*X(148)-JVS(1395)*X(149)-JVS(1396)*X(150)-JVS(1397)*X(151)-JVS(1398)*X(153)&
             &-JVS(1399)*X(154)-JVS(1400)*X(155)-JVS(1401)*X(156)-JVS(1402)*X(157)-JVS(1403)*X(159)-JVS(1404)*X(160)&
             &-JVS(1405)*X(161)-JVS(1406)*X(162)-JVS(1407)*X(163)-JVS(1408)*X(164)
  X(166) = X(166)-JVS(1423)*X(52)-JVS(1424)*X(69)-JVS(1425)*X(73)-JVS(1426)*X(88)-JVS(1427)*X(89)-JVS(1428)*X(91)&
             &-JVS(1429)*X(92)-JVS(1430)*X(98)-JVS(1431)*X(103)-JVS(1432)*X(104)-JVS(1433)*X(105)-JVS(1434)*X(109)-JVS(1435)&
             &*X(113)-JVS(1436)*X(114)-JVS(1437)*X(115)-JVS(1438)*X(116)-JVS(1439)*X(117)-JVS(1440)*X(122)-JVS(1441)*X(124)&
             &-JVS(1442)*X(125)-JVS(1443)*X(126)-JVS(1444)*X(129)-JVS(1445)*X(130)-JVS(1446)*X(131)-JVS(1447)*X(132)&
             &-JVS(1448)*X(137)-JVS(1449)*X(138)-JVS(1450)*X(139)-JVS(1451)*X(144)-JVS(1452)*X(146)-JVS(1453)*X(147)&
             &-JVS(1454)*X(148)-JVS(1455)*X(149)-JVS(1456)*X(150)-JVS(1457)*X(151)-JVS(1458)*X(152)-JVS(1459)*X(153)&
             &-JVS(1460)*X(154)-JVS(1461)*X(155)-JVS(1462)*X(156)-JVS(1463)*X(157)-JVS(1464)*X(159)-JVS(1465)*X(160)&
             &-JVS(1466)*X(161)-JVS(1467)*X(162)-JVS(1468)*X(163)-JVS(1469)*X(164)-JVS(1470)*X(165)
  X(167) = X(167)-JVS(1484)*X(51)-JVS(1485)*X(55)-JVS(1486)*X(58)-JVS(1487)*X(62)-JVS(1488)*X(72)-JVS(1489)*X(73)&
             &-JVS(1490)*X(76)-JVS(1491)*X(111)-JVS(1492)*X(114)-JVS(1493)*X(115)-JVS(1494)*X(116)-JVS(1495)*X(117)&
             &-JVS(1496)*X(118)-JVS(1497)*X(120)-JVS(1498)*X(121)-JVS(1499)*X(123)-JVS(1500)*X(124)-JVS(1501)*X(125)&
             &-JVS(1502)*X(127)-JVS(1503)*X(130)-JVS(1504)*X(131)-JVS(1505)*X(132)-JVS(1506)*X(133)-JVS(1507)*X(134)&
             &-JVS(1508)*X(135)-JVS(1509)*X(136)-JVS(1510)*X(138)-JVS(1511)*X(139)-JVS(1512)*X(141)-JVS(1513)*X(143)&
             &-JVS(1514)*X(144)-JVS(1515)*X(146)-JVS(1516)*X(147)-JVS(1517)*X(148)-JVS(1518)*X(149)-JVS(1519)*X(150)&
             &-JVS(1520)*X(151)-JVS(1521)*X(153)-JVS(1522)*X(154)-JVS(1523)*X(155)-JVS(1524)*X(156)-JVS(1525)*X(157)&
             &-JVS(1526)*X(159)-JVS(1527)*X(160)-JVS(1528)*X(161)-JVS(1529)*X(162)-JVS(1530)*X(163)-JVS(1531)*X(164)&
             &-JVS(1532)*X(166)
  X(168) = X(168)-JVS(1545)*X(93)-JVS(1546)*X(97)-JVS(1547)*X(103)-JVS(1548)*X(108)-JVS(1549)*X(114)-JVS(1550)*X(117)&
             &-JVS(1551)*X(123)-JVS(1552)*X(124)-JVS(1553)*X(129)-JVS(1554)*X(136)-JVS(1555)*X(138)-JVS(1556)*X(144)&
             &-JVS(1557)*X(147)-JVS(1558)*X(148)-JVS(1559)*X(150)-JVS(1560)*X(151)-JVS(1561)*X(157)-JVS(1562)*X(159)&
             &-JVS(1563)*X(160)-JVS(1564)*X(161)-JVS(1565)*X(162)-JVS(1566)*X(163)-JVS(1567)*X(164)-JVS(1568)*X(165)&
             &-JVS(1569)*X(166)-JVS(1570)*X(167)
  X(169) = X(169)-JVS(1584)*X(58)-JVS(1585)*X(60)-JVS(1586)*X(61)-JVS(1587)*X(70)-JVS(1588)*X(72)-JVS(1589)*X(73)&
             &-JVS(1590)*X(76)-JVS(1591)*X(77)-JVS(1592)*X(79)-JVS(1593)*X(83)-JVS(1594)*X(84)-JVS(1595)*X(85)-JVS(1596)&
             &*X(87)-JVS(1597)*X(88)-JVS(1598)*X(90)-JVS(1599)*X(91)-JVS(1600)*X(92)-JVS(1601)*X(93)-JVS(1602)*X(95)&
             &-JVS(1603)*X(96)-JVS(1604)*X(97)-JVS(1605)*X(98)-JVS(1606)*X(99)-JVS(1607)*X(100)-JVS(1608)*X(101)-JVS(1609)&
             &*X(102)-JVS(1610)*X(108)-JVS(1611)*X(111)-JVS(1612)*X(114)-JVS(1613)*X(117)-JVS(1614)*X(118)-JVS(1615)*X(120)&
             &-JVS(1616)*X(121)-JVS(1617)*X(122)-JVS(1618)*X(123)-JVS(1619)*X(124)-JVS(1620)*X(126)-JVS(1621)*X(127)&
             &-JVS(1622)*X(128)-JVS(1623)*X(129)-JVS(1624)*X(130)-JVS(1625)*X(131)-JVS(1626)*X(132)-JVS(1627)*X(133)&
             &-JVS(1628)*X(134)-JVS(1629)*X(135)-JVS(1630)*X(136)-JVS(1631)*X(137)-JVS(1632)*X(138)-JVS(1633)*X(139)&
             &-JVS(1634)*X(141)-JVS(1635)*X(143)-JVS(1636)*X(144)-JVS(1637)*X(146)-JVS(1638)*X(147)-JVS(1639)*X(148)&
             &-JVS(1640)*X(149)-JVS(1641)*X(150)-JVS(1642)*X(151)-JVS(1643)*X(152)-JVS(1644)*X(153)-JVS(1645)*X(154)&
             &-JVS(1646)*X(155)-JVS(1647)*X(156)-JVS(1648)*X(157)-JVS(1649)*X(158)-JVS(1650)*X(159)-JVS(1651)*X(160)&
             &-JVS(1652)*X(161)-JVS(1653)*X(162)-JVS(1654)*X(163)-JVS(1655)*X(164)-JVS(1656)*X(165)-JVS(1657)*X(166)&
             &-JVS(1658)*X(167)-JVS(1659)*X(168)
  X(170) = X(170)-JVS(1673)*X(36)-JVS(1674)*X(39)-JVS(1675)*X(52)-JVS(1676)*X(54)-JVS(1677)*X(55)-JVS(1678)*X(56)&
             &-JVS(1679)*X(57)-JVS(1680)*X(59)-JVS(1681)*X(60)-JVS(1682)*X(61)-JVS(1683)*X(62)-JVS(1684)*X(63)-JVS(1685)&
             &*X(64)-JVS(1686)*X(65)-JVS(1687)*X(66)-JVS(1688)*X(67)-JVS(1689)*X(68)-JVS(1690)*X(69)-JVS(1691)*X(70)&
             &-JVS(1692)*X(71)-JVS(1693)*X(72)-JVS(1694)*X(73)-JVS(1695)*X(74)-JVS(1696)*X(76)-JVS(1697)*X(77)-JVS(1698)&
             &*X(79)-JVS(1699)*X(80)-JVS(1700)*X(81)-JVS(1701)*X(82)-JVS(1702)*X(83)-JVS(1703)*X(84)-JVS(1704)*X(85)&
             &-JVS(1705)*X(86)-JVS(1706)*X(87)-JVS(1707)*X(88)-JVS(1708)*X(89)-JVS(1709)*X(90)-JVS(1710)*X(91)-JVS(1711)&
             &*X(92)-JVS(1712)*X(93)-JVS(1713)*X(94)-JVS(1714)*X(95)-JVS(1715)*X(96)-JVS(1716)*X(97)-JVS(1717)*X(98)&
             &-JVS(1718)*X(99)-JVS(1719)*X(100)-JVS(1720)*X(101)-JVS(1721)*X(102)-JVS(1722)*X(103)-JVS(1723)*X(104)&
             &-JVS(1724)*X(105)-JVS(1725)*X(106)-JVS(1726)*X(107)-JVS(1727)*X(108)-JVS(1728)*X(109)-JVS(1729)*X(110)&
             &-JVS(1730)*X(111)-JVS(1731)*X(112)-JVS(1732)*X(113)-JVS(1733)*X(114)-JVS(1734)*X(115)-JVS(1735)*X(116)&
             &-JVS(1736)*X(117)-JVS(1737)*X(118)-JVS(1738)*X(119)-JVS(1739)*X(120)-JVS(1740)*X(121)-JVS(1741)*X(122)&
             &-JVS(1742)*X(123)-JVS(1743)*X(124)-JVS(1744)*X(125)-JVS(1745)*X(126)-JVS(1746)*X(127)-JVS(1747)*X(128)&
             &-JVS(1748)*X(129)-JVS(1749)*X(130)-JVS(1750)*X(131)-JVS(1751)*X(132)-JVS(1752)*X(133)-JVS(1753)*X(134)&
             &-JVS(1754)*X(135)-JVS(1755)*X(136)-JVS(1756)*X(137)-JVS(1757)*X(138)-JVS(1758)*X(139)-JVS(1759)*X(140)&
             &-JVS(1760)*X(141)-JVS(1761)*X(142)-JVS(1762)*X(143)-JVS(1763)*X(144)-JVS(1764)*X(145)-JVS(1765)*X(146)&
             &-JVS(1766)*X(147)-JVS(1767)*X(148)-JVS(1768)*X(149)-JVS(1769)*X(150)-JVS(1770)*X(151)-JVS(1771)*X(152)&
             &-JVS(1772)*X(153)-JVS(1773)*X(154)-JVS(1774)*X(155)-JVS(1775)*X(156)-JVS(1776)*X(157)-JVS(1777)*X(158)&
             &-JVS(1778)*X(159)-JVS(1779)*X(160)-JVS(1780)*X(161)-JVS(1781)*X(162)-JVS(1782)*X(163)-JVS(1783)*X(164)&
             &-JVS(1784)*X(165)-JVS(1785)*X(166)-JVS(1786)*X(167)-JVS(1787)*X(168)-JVS(1788)*X(169)
  X(171) = X(171)-JVS(1801)*X(41)-JVS(1802)*X(42)-JVS(1803)*X(43)-JVS(1804)*X(44)-JVS(1805)*X(45)-JVS(1806)*X(46)&
             &-JVS(1807)*X(47)-JVS(1808)*X(48)-JVS(1809)*X(50)-JVS(1810)*X(52)-JVS(1811)*X(53)-JVS(1812)*X(56)-JVS(1813)&
             &*X(57)-JVS(1814)*X(63)-JVS(1815)*X(65)-JVS(1816)*X(66)-JVS(1817)*X(67)-JVS(1818)*X(68)-JVS(1819)*X(108)&
             &-JVS(1820)*X(110)-JVS(1821)*X(119)-JVS(1822)*X(123)-JVS(1823)*X(128)-JVS(1824)*X(140)-JVS(1825)*X(142)&
             &-JVS(1826)*X(146)-JVS(1827)*X(151)-JVS(1828)*X(158)-JVS(1829)*X(159)-JVS(1830)*X(161)-JVS(1831)*X(162)&
             &-JVS(1832)*X(163)-JVS(1833)*X(164)-JVS(1834)*X(165)-JVS(1835)*X(166)-JVS(1836)*X(167)-JVS(1837)*X(168)&
             &-JVS(1838)*X(169)-JVS(1839)*X(170)
  X(172) = X(172)-JVS(1851)*X(69)-JVS(1852)*X(89)-JVS(1853)*X(125)-JVS(1854)*X(139)-JVS(1855)*X(140)-JVS(1856)*X(142)&
             &-JVS(1857)*X(155)-JVS(1858)*X(156)-JVS(1859)*X(158)-JVS(1860)*X(160)-JVS(1861)*X(161)-JVS(1862)*X(162)&
             &-JVS(1863)*X(163)-JVS(1864)*X(164)-JVS(1865)*X(165)-JVS(1866)*X(166)-JVS(1867)*X(167)-JVS(1868)*X(168)&
             &-JVS(1869)*X(169)-JVS(1870)*X(170)-JVS(1871)*X(171)
  X(173) = X(173)-JVS(1882)*X(49)-JVS(1883)*X(53)-JVS(1884)*X(71)-JVS(1885)*X(98)-JVS(1886)*X(99)-JVS(1887)*X(100)&
             &-JVS(1888)*X(102)-JVS(1889)*X(104)-JVS(1890)*X(105)-JVS(1891)*X(109)-JVS(1892)*X(111)-JVS(1893)*X(112)&
             &-JVS(1894)*X(113)-JVS(1895)*X(114)-JVS(1896)*X(116)-JVS(1897)*X(117)-JVS(1898)*X(118)-JVS(1899)*X(120)&
             &-JVS(1900)*X(121)-JVS(1901)*X(126)-JVS(1902)*X(127)-JVS(1903)*X(129)-JVS(1904)*X(130)-JVS(1905)*X(131)&
             &-JVS(1906)*X(132)-JVS(1907)*X(133)-JVS(1908)*X(134)-JVS(1909)*X(135)-JVS(1910)*X(136)-JVS(1911)*X(138)&
             &-JVS(1912)*X(139)-JVS(1913)*X(141)-JVS(1914)*X(143)-JVS(1915)*X(144)-JVS(1916)*X(146)-JVS(1917)*X(147)&
             &-JVS(1918)*X(148)-JVS(1919)*X(150)-JVS(1920)*X(151)-JVS(1921)*X(153)-JVS(1922)*X(154)-JVS(1923)*X(155)&
             &-JVS(1924)*X(156)-JVS(1925)*X(157)-JVS(1926)*X(158)-JVS(1927)*X(159)-JVS(1928)*X(160)-JVS(1929)*X(161)&
             &-JVS(1930)*X(163)-JVS(1931)*X(164)-JVS(1932)*X(166)-JVS(1933)*X(167)-JVS(1934)*X(168)-JVS(1935)*X(169)&
             &-JVS(1936)*X(170)-JVS(1937)*X(171)-JVS(1938)*X(172)
  X(174) = X(174)-JVS(1948)*X(36)-JVS(1949)*X(65)-JVS(1950)*X(66)-JVS(1951)*X(67)-JVS(1952)*X(68)-JVS(1953)*X(71)&
             &-JVS(1954)*X(72)-JVS(1955)*X(73)-JVS(1956)*X(76)-JVS(1957)*X(77)-JVS(1958)*X(86)-JVS(1959)*X(89)-JVS(1960)&
             &*X(94)-JVS(1961)*X(107)-JVS(1962)*X(108)-JVS(1963)*X(119)-JVS(1964)*X(123)-JVS(1965)*X(125)-JVS(1966)*X(128)&
             &-JVS(1967)*X(135)-JVS(1968)*X(139)-JVS(1969)*X(140)-JVS(1970)*X(142)-JVS(1971)*X(143)-JVS(1972)*X(145)&
             &-JVS(1973)*X(146)-JVS(1974)*X(147)-JVS(1975)*X(148)-JVS(1976)*X(150)-JVS(1977)*X(151)-JVS(1978)*X(152)&
             &-JVS(1979)*X(153)-JVS(1980)*X(154)-JVS(1981)*X(155)-JVS(1982)*X(156)-JVS(1983)*X(157)-JVS(1984)*X(158)&
             &-JVS(1985)*X(159)-JVS(1986)*X(160)-JVS(1987)*X(161)-JVS(1988)*X(162)-JVS(1989)*X(163)-JVS(1990)*X(164)&
             &-JVS(1991)*X(165)-JVS(1992)*X(166)-JVS(1993)*X(167)-JVS(1994)*X(168)-JVS(1995)*X(169)-JVS(1996)*X(170)&
             &-JVS(1997)*X(171)-JVS(1998)*X(172)-JVS(1999)*X(173)
  X(175) = X(175)-JVS(2008)*X(51)-JVS(2009)*X(54)-JVS(2010)*X(58)-JVS(2011)*X(62)-JVS(2012)*X(77)-JVS(2013)*X(89)&
             &-JVS(2014)*X(94)-JVS(2015)*X(99)-JVS(2016)*X(103)-JVS(2017)*X(104)-JVS(2018)*X(105)-JVS(2019)*X(106)-JVS(2020)&
             &*X(107)-JVS(2021)*X(109)-JVS(2022)*X(112)-JVS(2023)*X(113)-JVS(2024)*X(114)-JVS(2025)*X(116)-JVS(2026)*X(117)&
             &-JVS(2027)*X(118)-JVS(2028)*X(122)-JVS(2029)*X(126)-JVS(2030)*X(129)-JVS(2031)*X(132)-JVS(2032)*X(133)&
             &-JVS(2033)*X(137)-JVS(2034)*X(138)-JVS(2035)*X(140)-JVS(2036)*X(144)-JVS(2037)*X(145)-JVS(2038)*X(146)&
             &-JVS(2039)*X(147)-JVS(2040)*X(148)-JVS(2041)*X(150)-JVS(2042)*X(151)-JVS(2043)*X(152)-JVS(2044)*X(153)&
             &-JVS(2045)*X(154)-JVS(2046)*X(155)-JVS(2047)*X(156)-JVS(2048)*X(157)-JVS(2049)*X(158)-JVS(2050)*X(159)&
             &-JVS(2051)*X(160)-JVS(2052)*X(161)-JVS(2053)*X(162)-JVS(2054)*X(163)-JVS(2055)*X(164)-JVS(2056)*X(165)&
             &-JVS(2057)*X(166)-JVS(2058)*X(167)-JVS(2059)*X(168)-JVS(2060)*X(169)-JVS(2061)*X(170)-JVS(2062)*X(171)&
             &-JVS(2063)*X(172)-JVS(2064)*X(173)-JVS(2065)*X(174)
  X(176) = X(176)-JVS(2073)*X(38)-JVS(2074)*X(47)-JVS(2075)*X(48)-JVS(2076)*X(50)-JVS(2077)*X(56)-JVS(2078)*X(57)&
             &-JVS(2079)*X(69)-JVS(2080)*X(72)-JVS(2081)*X(78)-JVS(2082)*X(81)-JVS(2083)*X(89)-JVS(2084)*X(107)-JVS(2085)&
             &*X(119)-JVS(2086)*X(125)-JVS(2087)*X(139)-JVS(2088)*X(140)-JVS(2089)*X(142)-JVS(2090)*X(155)-JVS(2091)*X(156)&
             &-JVS(2092)*X(158)-JVS(2093)*X(160)-JVS(2094)*X(161)-JVS(2095)*X(162)-JVS(2096)*X(163)-JVS(2097)*X(164)&
             &-JVS(2098)*X(165)-JVS(2099)*X(166)-JVS(2100)*X(167)-JVS(2101)*X(168)-JVS(2102)*X(169)-JVS(2103)*X(170)&
             &-JVS(2104)*X(171)-JVS(2105)*X(172)-JVS(2106)*X(173)-JVS(2107)*X(174)-JVS(2108)*X(175)
  X(177) = X(177)-JVS(2115)*X(41)-JVS(2116)*X(42)-JVS(2117)*X(43)-JVS(2118)*X(44)-JVS(2119)*X(45)-JVS(2120)*X(46)&
             &-JVS(2121)*X(47)-JVS(2122)*X(48)-JVS(2123)*X(49)-JVS(2124)*X(50)-JVS(2125)*X(53)-JVS(2126)*X(56)-JVS(2127)&
             &*X(57)-JVS(2128)*X(65)-JVS(2129)*X(66)-JVS(2130)*X(67)-JVS(2131)*X(68)-JVS(2132)*X(72)-JVS(2133)*X(110)&
             &-JVS(2134)*X(123)-JVS(2135)*X(140)-JVS(2136)*X(142)-JVS(2137)*X(158)-JVS(2138)*X(159)-JVS(2139)*X(162)&
             &-JVS(2140)*X(163)-JVS(2141)*X(164)-JVS(2142)*X(166)-JVS(2143)*X(167)-JVS(2144)*X(168)-JVS(2145)*X(169)&
             &-JVS(2146)*X(170)-JVS(2147)*X(171)-JVS(2148)*X(172)-JVS(2149)*X(173)-JVS(2150)*X(174)-JVS(2151)*X(175)&
             &-JVS(2152)*X(176)
  X(178) = X(178)-JVS(2158)*X(41)-JVS(2159)*X(42)-JVS(2160)*X(43)-JVS(2161)*X(44)-JVS(2162)*X(45)-JVS(2163)*X(46)&
             &-JVS(2164)*X(50)-JVS(2165)*X(59)-JVS(2166)*X(63)-JVS(2167)*X(65)-JVS(2168)*X(66)-JVS(2169)*X(67)-JVS(2170)&
             &*X(68)-JVS(2171)*X(75)-JVS(2172)*X(110)-JVS(2173)*X(140)-JVS(2174)*X(142)-JVS(2175)*X(158)-JVS(2176)*X(167)&
             &-JVS(2177)*X(168)-JVS(2178)*X(169)-JVS(2179)*X(170)-JVS(2180)*X(171)-JVS(2181)*X(172)-JVS(2182)*X(173)&
             &-JVS(2183)*X(174)-JVS(2184)*X(175)-JVS(2185)*X(176)-JVS(2186)*X(177)
  X(179) = X(179)-JVS(2191)*X(37)-JVS(2192)*X(38)-JVS(2193)*X(40)-JVS(2194)*X(51)-JVS(2195)*X(53)-JVS(2196)*X(58)&
             &-JVS(2197)*X(64)-JVS(2198)*X(71)-JVS(2199)*X(77)-JVS(2200)*X(82)-JVS(2201)*X(83)-JVS(2202)*X(94)-JVS(2203)&
             &*X(95)-JVS(2204)*X(96)-JVS(2205)*X(97)-JVS(2206)*X(98)-JVS(2207)*X(99)-JVS(2208)*X(100)-JVS(2209)*X(102)&
             &-JVS(2210)*X(103)-JVS(2211)*X(104)-JVS(2212)*X(105)-JVS(2213)*X(106)-JVS(2214)*X(107)-JVS(2215)*X(109)&
             &-JVS(2216)*X(111)-JVS(2217)*X(112)-JVS(2218)*X(113)-JVS(2219)*X(114)-JVS(2220)*X(115)-JVS(2221)*X(116)&
             &-JVS(2222)*X(117)-JVS(2223)*X(118)-JVS(2224)*X(120)-JVS(2225)*X(121)-JVS(2226)*X(124)-JVS(2227)*X(126)&
             &-JVS(2228)*X(127)-JVS(2229)*X(129)-JVS(2230)*X(130)-JVS(2231)*X(131)-JVS(2232)*X(132)-JVS(2233)*X(133)&
             &-JVS(2234)*X(134)-JVS(2235)*X(135)-JVS(2236)*X(136)-JVS(2237)*X(138)-JVS(2238)*X(139)-JVS(2239)*X(140)&
             &-JVS(2240)*X(141)-JVS(2241)*X(143)-JVS(2242)*X(144)-JVS(2243)*X(145)-JVS(2244)*X(146)-JVS(2245)*X(147)&
             &-JVS(2246)*X(148)-JVS(2247)*X(150)-JVS(2248)*X(151)-JVS(2249)*X(152)-JVS(2250)*X(153)-JVS(2251)*X(154)&
             &-JVS(2252)*X(155)-JVS(2253)*X(156)-JVS(2254)*X(157)-JVS(2255)*X(158)-JVS(2256)*X(159)-JVS(2257)*X(160)&
             &-JVS(2258)*X(161)-JVS(2259)*X(162)-JVS(2260)*X(163)-JVS(2261)*X(164)-JVS(2262)*X(165)-JVS(2263)*X(166)&
             &-JVS(2264)*X(167)-JVS(2265)*X(168)-JVS(2266)*X(169)-JVS(2267)*X(170)-JVS(2268)*X(171)-JVS(2269)*X(172)&
             &-JVS(2270)*X(173)-JVS(2271)*X(174)-JVS(2272)*X(175)-JVS(2273)*X(176)-JVS(2274)*X(177)-JVS(2275)*X(178)
  X(180) = X(180)-JVS(2279)*X(36)-JVS(2280)*X(41)-JVS(2281)*X(42)-JVS(2282)*X(43)-JVS(2283)*X(44)-JVS(2284)*X(45)&
             &-JVS(2285)*X(46)-JVS(2286)*X(50)-JVS(2287)*X(59)-JVS(2288)*X(64)-JVS(2289)*X(65)-JVS(2290)*X(66)-JVS(2291)&
             &*X(67)-JVS(2292)*X(68)-JVS(2293)*X(73)-JVS(2294)*X(75)-JVS(2295)*X(78)-JVS(2296)*X(94)-JVS(2297)*X(107)&
             &-JVS(2298)*X(110)-JVS(2299)*X(119)-JVS(2300)*X(123)-JVS(2301)*X(128)-JVS(2302)*X(140)-JVS(2303)*X(142)&
             &-JVS(2304)*X(146)-JVS(2305)*X(151)-JVS(2306)*X(158)-JVS(2307)*X(159)-JVS(2308)*X(161)-JVS(2309)*X(162)&
             &-JVS(2310)*X(163)-JVS(2311)*X(164)-JVS(2312)*X(165)-JVS(2313)*X(166)-JVS(2314)*X(167)-JVS(2315)*X(168)&
             &-JVS(2316)*X(169)-JVS(2317)*X(170)-JVS(2318)*X(171)-JVS(2319)*X(172)-JVS(2320)*X(173)-JVS(2321)*X(174)&
             &-JVS(2322)*X(175)-JVS(2323)*X(176)-JVS(2324)*X(177)-JVS(2325)*X(178)-JVS(2326)*X(179)
  X(181) = X(181)-JVS(2329)*X(73)-JVS(2330)*X(94)-JVS(2331)*X(107)-JVS(2332)*X(119)-JVS(2333)*X(123)-JVS(2334)*X(128)&
             &-JVS(2335)*X(140)-JVS(2336)*X(142)-JVS(2337)*X(146)-JVS(2338)*X(151)-JVS(2339)*X(158)-JVS(2340)*X(159)&
             &-JVS(2341)*X(161)-JVS(2342)*X(162)-JVS(2343)*X(163)-JVS(2344)*X(164)-JVS(2345)*X(165)-JVS(2346)*X(166)&
             &-JVS(2347)*X(167)-JVS(2348)*X(168)-JVS(2349)*X(169)-JVS(2350)*X(170)-JVS(2351)*X(171)-JVS(2352)*X(172)&
             &-JVS(2353)*X(173)-JVS(2354)*X(174)-JVS(2355)*X(175)-JVS(2356)*X(176)-JVS(2357)*X(177)-JVS(2358)*X(178)&
             &-JVS(2359)*X(179)-JVS(2360)*X(180)
  X(181) = X(181)/JVS(2361)
  X(180) = (X(180)-JVS(2328)*X(181))/(JVS(2327))
  X(179) = (X(179)-JVS(2277)*X(180)-JVS(2278)*X(181))/(JVS(2276))
  X(178) = (X(178)-JVS(2188)*X(179)-JVS(2189)*X(180)-JVS(2190)*X(181))/(JVS(2187))
  X(177) = (X(177)-JVS(2154)*X(178)-JVS(2155)*X(179)-JVS(2156)*X(180)-JVS(2157)*X(181))/(JVS(2153))
  X(176) = (X(176)-JVS(2110)*X(177)-JVS(2111)*X(178)-JVS(2112)*X(179)-JVS(2113)*X(180)-JVS(2114)*X(181))/(JVS(2109))
  X(175) = (X(175)-JVS(2067)*X(176)-JVS(2068)*X(177)-JVS(2069)*X(178)-JVS(2070)*X(179)-JVS(2071)*X(180)-JVS(2072)&
             &*X(181))/(JVS(2066))
  X(174) = (X(174)-JVS(2001)*X(175)-JVS(2002)*X(176)-JVS(2003)*X(177)-JVS(2004)*X(178)-JVS(2005)*X(179)-JVS(2006)*X(180)&
             &-JVS(2007)*X(181))/(JVS(2000))
  X(173) = (X(173)-JVS(1940)*X(174)-JVS(1941)*X(175)-JVS(1942)*X(176)-JVS(1943)*X(177)-JVS(1944)*X(178)-JVS(1945)*X(179)&
             &-JVS(1946)*X(180)-JVS(1947)*X(181))/(JVS(1939))
  X(172) = (X(172)-JVS(1873)*X(173)-JVS(1874)*X(174)-JVS(1875)*X(175)-JVS(1876)*X(176)-JVS(1877)*X(177)-JVS(1878)*X(178)&
             &-JVS(1879)*X(179)-JVS(1880)*X(180)-JVS(1881)*X(181))/(JVS(1872))
  X(171) = (X(171)-JVS(1841)*X(172)-JVS(1842)*X(173)-JVS(1843)*X(174)-JVS(1844)*X(175)-JVS(1845)*X(176)-JVS(1846)*X(177)&
             &-JVS(1847)*X(178)-JVS(1848)*X(179)-JVS(1849)*X(180)-JVS(1850)*X(181))/(JVS(1840))
  X(170) = (X(170)-JVS(1790)*X(171)-JVS(1791)*X(172)-JVS(1792)*X(173)-JVS(1793)*X(174)-JVS(1794)*X(175)-JVS(1795)*X(176)&
             &-JVS(1796)*X(177)-JVS(1797)*X(178)-JVS(1798)*X(179)-JVS(1799)*X(180)-JVS(1800)*X(181))/(JVS(1789))
  X(169) = (X(169)-JVS(1661)*X(170)-JVS(1662)*X(171)-JVS(1663)*X(172)-JVS(1664)*X(173)-JVS(1665)*X(174)-JVS(1666)*X(175)&
             &-JVS(1667)*X(176)-JVS(1668)*X(177)-JVS(1669)*X(178)-JVS(1670)*X(179)-JVS(1671)*X(180)-JVS(1672)*X(181))&
             &/(JVS(1660))
  X(168) = (X(168)-JVS(1572)*X(169)-JVS(1573)*X(170)-JVS(1574)*X(171)-JVS(1575)*X(172)-JVS(1576)*X(173)-JVS(1577)*X(175)&
             &-JVS(1578)*X(176)-JVS(1579)*X(177)-JVS(1580)*X(178)-JVS(1581)*X(179)-JVS(1582)*X(180)-JVS(1583)*X(181))&
             &/(JVS(1571))
  X(167) = (X(167)-JVS(1534)*X(168)-JVS(1535)*X(169)-JVS(1536)*X(170)-JVS(1537)*X(171)-JVS(1538)*X(173)-JVS(1539)*X(175)&
             &-JVS(1540)*X(176)-JVS(1541)*X(177)-JVS(1542)*X(178)-JVS(1543)*X(179)-JVS(1544)*X(180))/(JVS(1533))
  X(166) = (X(166)-JVS(1472)*X(167)-JVS(1473)*X(168)-JVS(1474)*X(169)-JVS(1475)*X(170)-JVS(1476)*X(171)-JVS(1477)*X(173)&
             &-JVS(1478)*X(175)-JVS(1479)*X(176)-JVS(1480)*X(177)-JVS(1481)*X(178)-JVS(1482)*X(179)-JVS(1483)*X(180))&
             &/(JVS(1471))
  X(165) = (X(165)-JVS(1410)*X(166)-JVS(1411)*X(167)-JVS(1412)*X(168)-JVS(1413)*X(169)-JVS(1414)*X(170)-JVS(1415)*X(171)&
             &-JVS(1416)*X(173)-JVS(1417)*X(175)-JVS(1418)*X(176)-JVS(1419)*X(177)-JVS(1420)*X(178)-JVS(1421)*X(179)&
             &-JVS(1422)*X(180))/(JVS(1409))
  X(164) = (X(164)-JVS(1340)*X(166)-JVS(1341)*X(167)-JVS(1342)*X(168)-JVS(1343)*X(169)-JVS(1344)*X(170)-JVS(1345)*X(171)&
             &-JVS(1346)*X(173)-JVS(1347)*X(175)-JVS(1348)*X(176)-JVS(1349)*X(179))/(JVS(1339))
  X(163) = (X(163)-JVS(1286)*X(164)-JVS(1287)*X(166)-JVS(1288)*X(167)-JVS(1289)*X(168)-JVS(1290)*X(169)-JVS(1291)*X(170)&
             &-JVS(1292)*X(171)-JVS(1293)*X(173)-JVS(1294)*X(175)-JVS(1295)*X(179))/(JVS(1285))
  X(162) = (X(162)-JVS(1259)*X(163)-JVS(1260)*X(164)-JVS(1261)*X(166)-JVS(1262)*X(167)-JVS(1263)*X(168)-JVS(1264)*X(169)&
             &-JVS(1265)*X(170)-JVS(1266)*X(173)-JVS(1267)*X(175)-JVS(1268)*X(176)-JVS(1269)*X(179))/(JVS(1258))
  X(161) = (X(161)-JVS(1226)*X(163)-JVS(1227)*X(164)-JVS(1228)*X(166)-JVS(1229)*X(167)-JVS(1230)*X(168)-JVS(1231)*X(169)&
             &-JVS(1232)*X(170)-JVS(1233)*X(173)-JVS(1234)*X(175)-JVS(1235)*X(179))/(JVS(1225))
  X(160) = (X(160)-JVS(1208)*X(161)-JVS(1209)*X(163)-JVS(1210)*X(164)-JVS(1211)*X(166)-JVS(1212)*X(167)-JVS(1213)*X(168)&
             &-JVS(1214)*X(169)-JVS(1215)*X(170)-JVS(1216)*X(173)-JVS(1217)*X(175)-JVS(1218)*X(176)-JVS(1219)*X(179))&
             &/(JVS(1207))
  X(159) = (X(159)-JVS(1175)*X(163)-JVS(1176)*X(164)-JVS(1177)*X(166)-JVS(1178)*X(167)-JVS(1179)*X(168)-JVS(1180)*X(169)&
             &-JVS(1181)*X(170)-JVS(1182)*X(173)-JVS(1183)*X(175)-JVS(1184)*X(179))/(JVS(1174))
  X(158) = (X(158)-JVS(1156)*X(168)-JVS(1157)*X(169)-JVS(1158)*X(170)-JVS(1159)*X(171)-JVS(1160)*X(172)-JVS(1161)*X(173)&
             &-JVS(1162)*X(174)-JVS(1163)*X(175)-JVS(1164)*X(176)-JVS(1165)*X(177)-JVS(1166)*X(178)-JVS(1167)*X(179)&
             &-JVS(1168)*X(181))/(JVS(1155))
  X(157) = (X(157)-JVS(1133)*X(159)-JVS(1134)*X(160)-JVS(1135)*X(161)-JVS(1136)*X(163)-JVS(1137)*X(164)-JVS(1138)*X(166)&
             &-JVS(1139)*X(167)-JVS(1140)*X(168)-JVS(1141)*X(169)-JVS(1142)*X(170)-JVS(1143)*X(173)-JVS(1144)*X(175)&
             &-JVS(1145)*X(176)-JVS(1146)*X(179))/(JVS(1132))
  X(156) = (X(156)-JVS(1090)*X(160)-JVS(1091)*X(161)-JVS(1092)*X(164)-JVS(1093)*X(167)-JVS(1094)*X(168)-JVS(1095)*X(169)&
             &-JVS(1096)*X(170)-JVS(1097)*X(173)-JVS(1098)*X(175)-JVS(1099)*X(176)-JVS(1100)*X(179))/(JVS(1089))
  X(155) = (X(155)-JVS(1067)*X(156)-JVS(1068)*X(161)-JVS(1069)*X(164)-JVS(1070)*X(167)-JVS(1071)*X(168)-JVS(1072)*X(169)&
             &-JVS(1073)*X(170)-JVS(1074)*X(173)-JVS(1075)*X(175))/(JVS(1066))
  X(154) = (X(154)-JVS(1048)*X(161)-JVS(1049)*X(164)-JVS(1050)*X(167)-JVS(1051)*X(168)-JVS(1052)*X(169)-JVS(1053)*X(170)&
             &-JVS(1054)*X(173)-JVS(1055)*X(175))/(JVS(1047))
  X(153) = (X(153)-JVS(1032)*X(154)-JVS(1033)*X(161)-JVS(1034)*X(164)-JVS(1035)*X(167)-JVS(1036)*X(168)-JVS(1037)*X(169)&
             &-JVS(1038)*X(170)-JVS(1039)*X(173)-JVS(1040)*X(175))/(JVS(1031))
  X(152) = (X(152)-JVS(1009)*X(153)-JVS(1010)*X(154)-JVS(1011)*X(155)-JVS(1012)*X(156)-JVS(1013)*X(159)-JVS(1014)*X(160)&
             &-JVS(1015)*X(161)-JVS(1016)*X(163)-JVS(1017)*X(164)-JVS(1018)*X(166)-JVS(1019)*X(167)-JVS(1020)*X(168)&
             &-JVS(1021)*X(169)-JVS(1022)*X(170)-JVS(1023)*X(173)-JVS(1024)*X(175)-JVS(1025)*X(176)-JVS(1026)*X(179))&
             &/(JVS(1008))
  X(151) = (X(151)-JVS(977)*X(164)-JVS(978)*X(167)-JVS(979)*X(168)-JVS(980)*X(169)-JVS(981)*X(170)-JVS(982)*X(173)&
             &-JVS(983)*X(175))/(JVS(976))
  X(150) = (X(150)-JVS(964)*X(164)-JVS(965)*X(167)-JVS(966)*X(168)-JVS(967)*X(169)-JVS(968)*X(170)-JVS(969)*X(173)&
             &-JVS(970)*X(175))/(JVS(963))
  X(149) = (X(149)-JVS(938)*X(150)-JVS(939)*X(151)-JVS(940)*X(153)-JVS(941)*X(154)-JVS(942)*X(155)-JVS(943)*X(156)&
             &-JVS(944)*X(159)-JVS(945)*X(160)-JVS(946)*X(161)-JVS(947)*X(163)-JVS(948)*X(164)-JVS(949)*X(166)-JVS(950)&
             &*X(167)-JVS(951)*X(168)-JVS(952)*X(169)-JVS(953)*X(170)-JVS(954)*X(173)-JVS(955)*X(175)-JVS(956)*X(176)&
             &-JVS(957)*X(179))/(JVS(937))
  X(148) = (X(148)-JVS(909)*X(164)-JVS(910)*X(167)-JVS(911)*X(168)-JVS(912)*X(169)-JVS(913)*X(170)-JVS(914)*X(173)&
             &-JVS(915)*X(175))/(JVS(908))
  X(147) = (X(147)-JVS(896)*X(150)-JVS(897)*X(161)-JVS(898)*X(164)-JVS(899)*X(167)-JVS(900)*X(168)-JVS(901)*X(169)&
             &-JVS(902)*X(170)-JVS(903)*X(173)-JVS(904)*X(175)-JVS(905)*X(179))/(JVS(895))
  X(146) = (X(146)-JVS(884)*X(163)-JVS(885)*X(166)-JVS(886)*X(168)-JVS(887)*X(170)-JVS(888)*X(173)-JVS(889)*X(175)&
             &-JVS(890)*X(179))/(JVS(883))
  X(145) = (X(145)-JVS(851)*X(147)-JVS(852)*X(148)-JVS(853)*X(150)-JVS(854)*X(151)-JVS(855)*X(152)-JVS(856)*X(153)&
             &-JVS(857)*X(154)-JVS(858)*X(157)-JVS(859)*X(158)-JVS(860)*X(159)-JVS(861)*X(160)-JVS(862)*X(161)-JVS(863)&
             &*X(162)-JVS(864)*X(163)-JVS(865)*X(164)-JVS(866)*X(165)-JVS(867)*X(166)-JVS(868)*X(167)-JVS(869)*X(168)&
             &-JVS(870)*X(169)-JVS(871)*X(170)-JVS(872)*X(171)-JVS(873)*X(172)-JVS(874)*X(173)-JVS(875)*X(174)-JVS(876)&
             &*X(175)-JVS(877)*X(176)-JVS(878)*X(178)-JVS(879)*X(179)-JVS(880)*X(180)-JVS(881)*X(181))/(JVS(850))
  X(144) = (X(144)-JVS(830)*X(150)-JVS(831)*X(164)-JVS(832)*X(167)-JVS(833)*X(168)-JVS(834)*X(170)-JVS(835)*X(173)&
             &-JVS(836)*X(175))/(JVS(829))
  X(143) = (X(143)-JVS(819)*X(155)-JVS(820)*X(156)-JVS(821)*X(160)-JVS(822)*X(164)-JVS(823)*X(167)-JVS(824)*X(169)&
             &-JVS(825)*X(170)-JVS(826)*X(173)-JVS(827)*X(175)-JVS(828)*X(176))/(JVS(818))
  X(142) = (X(142)-JVS(801)*X(158)-JVS(802)*X(167)-JVS(803)*X(169)-JVS(804)*X(170)-JVS(805)*X(171)-JVS(806)*X(172)&
             &-JVS(807)*X(174)-JVS(808)*X(175)-JVS(809)*X(177)-JVS(810)*X(178)-JVS(811)*X(179)-JVS(812)*X(180)-JVS(813)&
             &*X(181))/(JVS(800))
  X(141) = (X(141)-JVS(784)*X(153)-JVS(785)*X(154)-JVS(786)*X(156)-JVS(787)*X(161)-JVS(788)*X(164)-JVS(789)*X(167)&
             &-JVS(790)*X(169)-JVS(791)*X(170)-JVS(792)*X(173)-JVS(793)*X(175))/(JVS(783))
  X(140) = (X(140)-JVS(773)*X(170)-JVS(774)*X(171)-JVS(775)*X(172)-JVS(776)*X(174)-JVS(777)*X(178)-JVS(778)*X(179)&
             &-JVS(779)*X(180)-JVS(780)*X(181))/(JVS(772))
  X(139) = (X(139)-JVS(764)*X(155)-JVS(765)*X(156)-JVS(766)*X(164)-JVS(767)*X(167)-JVS(768)*X(169)-JVS(769)*X(170)&
             &-JVS(770)*X(173)-JVS(771)*X(176))/(JVS(763))
  X(138) = (X(138)-JVS(755)*X(151)-JVS(756)*X(164)-JVS(757)*X(167)-JVS(758)*X(169)-JVS(759)*X(170)-JVS(760)*X(173))&
             &/(JVS(754))
  X(137) = (X(137)-JVS(736)*X(138)-JVS(737)*X(148)-JVS(738)*X(150)-JVS(739)*X(151)-JVS(740)*X(153)-JVS(741)*X(154)&
             &-JVS(742)*X(159)-JVS(743)*X(163)-JVS(744)*X(164)-JVS(745)*X(166)-JVS(746)*X(167)-JVS(747)*X(168)-JVS(748)&
             &*X(169)-JVS(749)*X(170)-JVS(750)*X(173)-JVS(751)*X(175)-JVS(752)*X(179))/(JVS(735))
  X(136) = (X(136)-JVS(716)*X(144)-JVS(717)*X(157)-JVS(718)*X(159)-JVS(719)*X(160)-JVS(720)*X(164)-JVS(721)*X(167)&
             &-JVS(722)*X(169)-JVS(723)*X(170)-JVS(724)*X(173)-JVS(725)*X(175)-JVS(726)*X(179))/(JVS(715))
  X(135) = (X(135)-JVS(705)*X(160)-JVS(706)*X(164)-JVS(707)*X(167)-JVS(708)*X(169)-JVS(709)*X(170)-JVS(710)*X(173)&
             &-JVS(711)*X(175))/(JVS(704))
  X(134) = (X(134)-JVS(692)*X(136)-JVS(693)*X(155)-JVS(694)*X(156)-JVS(695)*X(157)-JVS(696)*X(160)-JVS(697)*X(164)&
             &-JVS(698)*X(167)-JVS(699)*X(169)-JVS(700)*X(170)-JVS(701)*X(173)-JVS(702)*X(175)-JVS(703)*X(176))/(JVS(691))
  X(133) = (X(133)-JVS(681)*X(159)-JVS(682)*X(164)-JVS(683)*X(167)-JVS(684)*X(168)-JVS(685)*X(169)-JVS(686)*X(170)&
             &-JVS(687)*X(173)-JVS(688)*X(175))/(JVS(680))
  X(132) = (X(132)-JVS(671)*X(146)-JVS(672)*X(161)-JVS(673)*X(164)-JVS(674)*X(167)-JVS(675)*X(169)-JVS(676)*X(170)&
             &-JVS(677)*X(173))/(JVS(670))
  X(131) = (X(131)-JVS(661)*X(159)-JVS(662)*X(164)-JVS(663)*X(167)-JVS(664)*X(168)-JVS(665)*X(169)-JVS(666)*X(170)&
             &-JVS(667)*X(173)-JVS(668)*X(175))/(JVS(660))
  X(130) = (X(130)-JVS(652)*X(161)-JVS(653)*X(164)-JVS(654)*X(167)-JVS(655)*X(169)-JVS(656)*X(173)-JVS(657)*X(175))&
             &/(JVS(651))
  X(129) = (X(129)-JVS(645)*X(144)-JVS(646)*X(169)-JVS(647)*X(170)-JVS(648)*X(173)-JVS(649)*X(175)-JVS(650)*X(179))&
             &/(JVS(644))
  X(128) = (X(128)-JVS(630)*X(146)-JVS(631)*X(151)-JVS(632)*X(159)-JVS(633)*X(161)-JVS(634)*X(163)-JVS(635)*X(166)&
             &-JVS(636)*X(168)-JVS(637)*X(169)-JVS(638)*X(170)-JVS(639)*X(171)-JVS(640)*X(173)-JVS(641)*X(175)-JVS(642)&
             &*X(179)-JVS(643)*X(180))/(JVS(629))
  X(127) = (X(127)-JVS(613)*X(159)-JVS(614)*X(164)-JVS(615)*X(167)-JVS(616)*X(168)-JVS(617)*X(169)-JVS(618)*X(170)&
             &-JVS(619)*X(173)-JVS(620)*X(175))/(JVS(612))
  X(126) = (X(126)-JVS(602)*X(132)-JVS(603)*X(148)-JVS(604)*X(153)-JVS(605)*X(154)-JVS(606)*X(168)-JVS(607)*X(169)&
             &-JVS(608)*X(170)-JVS(609)*X(173))/(JVS(601))
  X(125) = (X(125)-JVS(591)*X(139)-JVS(592)*X(155)-JVS(593)*X(156)-JVS(594)*X(164)-JVS(595)*X(167)-JVS(596)*X(169)&
             &-JVS(597)*X(170)-JVS(598)*X(173)-JVS(599)*X(176))/(JVS(590))
  X(124) = (X(124)-JVS(583)*X(148)-JVS(584)*X(150)-JVS(585)*X(167)-JVS(586)*X(168)-JVS(587)*X(170)-JVS(588)*X(173))&
             &/(JVS(582))
  X(123) = (X(123)-JVS(575)*X(159)-JVS(576)*X(162)-JVS(577)*X(168)-JVS(578)*X(170)-JVS(579)*X(175)-JVS(580)*X(177)&
             &-JVS(581)*X(180))/(JVS(574))
  X(122) = (X(122)-JVS(562)*X(137)-JVS(563)*X(138)-JVS(564)*X(144)-JVS(565)*X(148)-JVS(566)*X(164)-JVS(567)*X(167)&
             &-JVS(568)*X(168)-JVS(569)*X(169)-JVS(570)*X(170)-JVS(571)*X(173)-JVS(572)*X(175))/(JVS(561))
  X(121) = (X(121)-JVS(551)*X(147)-JVS(552)*X(164)-JVS(553)*X(167)-JVS(554)*X(169)-JVS(555)*X(170)-JVS(556)*X(173))&
             &/(JVS(550))
  X(120) = (X(120)-JVS(541)*X(155)-JVS(542)*X(156)-JVS(543)*X(164)-JVS(544)*X(167)-JVS(545)*X(169)-JVS(546)*X(170)&
             &-JVS(547)*X(173)-JVS(548)*X(176))/(JVS(540))
  X(119) = (X(119)-JVS(529)*X(158)-JVS(530)*X(169)-JVS(531)*X(170)-JVS(532)*X(171)-JVS(533)*X(172)-JVS(534)*X(174)&
             &-JVS(535)*X(176)-JVS(536)*X(179)-JVS(537)*X(181))/(JVS(528))
  X(118) = (X(118)-JVS(521)*X(144)-JVS(522)*X(167)-JVS(523)*X(169)-JVS(524)*X(173)-JVS(525)*X(175))/(JVS(520))
  X(117) = (X(117)-JVS(516)*X(159)-JVS(517)*X(168)-JVS(518)*X(170)-JVS(519)*X(175))/(JVS(515))
  X(116) = (X(116)-JVS(508)*X(159)-JVS(509)*X(163)-JVS(510)*X(166)-JVS(511)*X(168)-JVS(512)*X(173)-JVS(513)*X(179))&
             &/(JVS(507))
  X(115) = (X(115)-JVS(497)*X(124)-JVS(498)*X(130)-JVS(499)*X(131)-JVS(500)*X(154)-JVS(501)*X(164)-JVS(502)*X(167)&
             &-JVS(503)*X(168)-JVS(504)*X(169)-JVS(505)*X(170)-JVS(506)*X(173))/(JVS(496))
  X(114) = (X(114)-JVS(492)*X(168)-JVS(493)*X(170)-JVS(494)*X(175))/(JVS(491))
  X(113) = (X(113)-JVS(484)*X(151)-JVS(485)*X(161)-JVS(486)*X(163)-JVS(487)*X(166)-JVS(488)*X(168)-JVS(489)*X(173)&
             &-JVS(490)*X(179))/(JVS(483))
  X(112) = (X(112)-JVS(475)*X(114)-JVS(476)*X(117)-JVS(477)*X(159)-JVS(478)*X(161)-JVS(479)*X(163)-JVS(480)*X(168)&
             &-JVS(481)*X(173)-JVS(482)*X(179))/(JVS(474))
  X(111) = (X(111)-JVS(469)*X(144)-JVS(470)*X(167)-JVS(471)*X(169)-JVS(472)*X(170)-JVS(473)*X(173))/(JVS(468))
  X(110) = (X(110)-JVS(459)*X(140)-JVS(460)*X(142)-JVS(461)*X(158)-JVS(462)*X(167)-JVS(463)*X(170)-JVS(464)*X(177)&
             &-JVS(465)*X(178)-JVS(466)*X(180)-JVS(467)*X(181))/(JVS(458))
  X(109) = (X(109)-JVS(451)*X(151)-JVS(452)*X(163)-JVS(453)*X(166)-JVS(454)*X(168)-JVS(455)*X(173)-JVS(456)*X(179))&
             &/(JVS(450))
  X(108) = (X(108)-JVS(440)*X(123)-JVS(441)*X(165)-JVS(442)*X(168)-JVS(443)*X(169)-JVS(444)*X(170)-JVS(445)*X(171)&
             &-JVS(446)*X(172)-JVS(447)*X(177)-JVS(448)*X(180)-JVS(449)*X(181))/(JVS(439))
  X(107) = (X(107)-JVS(434)*X(158)-JVS(435)*X(174)-JVS(436)*X(176)-JVS(437)*X(179)-JVS(438)*X(181))/(JVS(433))
  X(106) = (X(106)-JVS(426)*X(133)-JVS(427)*X(148)-JVS(428)*X(153)-JVS(429)*X(168)-JVS(430)*X(169)-JVS(431)*X(170)&
             &-JVS(432)*X(173))/(JVS(425))
  X(105) = (X(105)-JVS(418)*X(117)-JVS(419)*X(163)-JVS(420)*X(166)-JVS(421)*X(168)-JVS(422)*X(173)-JVS(423)*X(179))&
             &/(JVS(417))
  X(104) = (X(104)-JVS(411)*X(114)-JVS(412)*X(163)-JVS(413)*X(166)-JVS(414)*X(168)-JVS(415)*X(173)-JVS(416)*X(179))&
             &/(JVS(410))
  X(103) = (X(103)-JVS(405)*X(129)-JVS(406)*X(147)-JVS(407)*X(168)-JVS(408)*X(170)-JVS(409)*X(179))/(JVS(404))
  X(102) = (X(102)-JVS(400)*X(148)-JVS(401)*X(164)-JVS(402)*X(169)-JVS(403)*X(173))/(JVS(399))
  X(101) = (X(101)-JVS(385)*X(120)-JVS(386)*X(121)-JVS(387)*X(127)-JVS(388)*X(131)-JVS(389)*X(132)-JVS(390)*X(133)&
             &-JVS(391)*X(135)-JVS(392)*X(138)-JVS(393)*X(139)-JVS(394)*X(141)-JVS(395)*X(148)-JVS(396)*X(155)-JVS(397)&
             &*X(167)-JVS(398)*X(170))/(JVS(384))
  X(100) = (X(100)-JVS(378)*X(138)-JVS(379)*X(164)-JVS(380)*X(168)-JVS(381)*X(169)-JVS(382)*X(170)-JVS(383)*X(173))&
             &/(JVS(377))
  X(99) = (X(99)-JVS(371)*X(126)-JVS(372)*X(169)-JVS(373)*X(170)-JVS(374)*X(173)-JVS(375)*X(179))/(JVS(370))
  X(98) = (X(98)-JVS(365)*X(148)-JVS(366)*X(169)-JVS(367)*X(170)-JVS(368)*X(173))/(JVS(364))
  X(97) = (X(97)-JVS(358)*X(148)-JVS(359)*X(168)-JVS(360)*X(170)-JVS(361)*X(173))/(JVS(357))
  X(96) = (X(96)-JVS(352)*X(130)-JVS(353)*X(153)-JVS(354)*X(154)-JVS(355)*X(169)-JVS(356)*X(170))/(JVS(351))
  X(95) = (X(95)-JVS(346)*X(111)-JVS(347)*X(118)-JVS(348)*X(150)-JVS(349)*X(169)-JVS(350)*X(170))/(JVS(345))
  X(94) = (X(94)-JVS(341)*X(174)-JVS(342)*X(175)-JVS(343)*X(179)-JVS(344)*X(181))/(JVS(340))
  X(93) = (X(93)-JVS(335)*X(138)-JVS(336)*X(164)-JVS(337)*X(168)-JVS(338)*X(170)-JVS(339)*X(173))/(JVS(334))
  X(92) = (X(92)-JVS(329)*X(138)-JVS(330)*X(164)-JVS(331)*X(169)-JVS(332)*X(170)-JVS(333)*X(173))/(JVS(328))
  X(91) = (X(91)-JVS(324)*X(138)-JVS(325)*X(169)-JVS(326)*X(170))/(JVS(323))
  X(90) = (X(90)-JVS(320)*X(133)-JVS(321)*X(169)-JVS(322)*X(170))/(JVS(319))
  X(89) = (X(89)-JVS(316)*X(170)-JVS(317)*X(175)-JVS(318)*X(176))/(JVS(315))
  X(88) = (X(88)-JVS(311)*X(132)-JVS(312)*X(146)-JVS(313)*X(169)-JVS(314)*X(170))/(JVS(310))
  X(87) = (X(87)-JVS(307)*X(148)-JVS(308)*X(169)-JVS(309)*X(170))/(JVS(306))
  X(86) = (X(86)-JVS(302)*X(135)-JVS(303)*X(143)-JVS(304)*X(169)-JVS(305)*X(170))/(JVS(301))
  X(85) = (X(85)-JVS(296)*X(100)-JVS(297)*X(102)-JVS(298)*X(155)-JVS(299)*X(169)-JVS(300)*X(170))/(JVS(295))
  X(84) = (X(84)-JVS(292)*X(127)-JVS(293)*X(169)-JVS(294)*X(170))/(JVS(291))
  X(83) = (X(83)-JVS(288)*X(131)-JVS(289)*X(169)-JVS(290)*X(170))/(JVS(287))
  X(82) = (X(82)-JVS(281)*X(124)-JVS(282)*X(154)-JVS(283)*X(168)-JVS(284)*X(169)-JVS(285)*X(170)-JVS(286)*X(173))&
            &/(JVS(280))
  X(81) = (X(81)-JVS(274)*X(107)-JVS(275)*X(119)-JVS(276)*X(158)-JVS(277)*X(170)-JVS(278)*X(172)-JVS(279)*X(176))&
            &/(JVS(273))
  X(80) = (X(80)-JVS(264)*X(104)-JVS(265)*X(105)-JVS(266)*X(109)-JVS(267)*X(112)-JVS(268)*X(113)-JVS(269)*X(116)&
            &-JVS(270)*X(146)-JVS(271)*X(163)-JVS(272)*X(170))/(JVS(263))
  X(79) = (X(79)-JVS(259)*X(129)-JVS(260)*X(136)-JVS(261)*X(169)-JVS(262)*X(170))/(JVS(258))
  X(78) = (X(78)-JVS(250)*X(107)-JVS(251)*X(119)-JVS(252)*X(140)-JVS(253)*X(142)-JVS(254)*X(158)-JVS(255)*X(172)&
            &-JVS(256)*X(178)-JVS(257)*X(181))/(JVS(249))
  X(77) = (X(77)-JVS(246)*X(169)-JVS(247)*X(170)-JVS(248)*X(179))/(JVS(245))
  X(76) = (X(76)-JVS(242)*X(167)-JVS(243)*X(169)-JVS(244)*X(170))/(JVS(241))
  X(75) = (X(75)-JVS(236)*X(158)-JVS(237)*X(167)-JVS(238)*X(170)-JVS(239)*X(178)-JVS(240)*X(180))/(JVS(235))
  X(74) = (X(74)-JVS(231)*X(147)-JVS(232)*X(169)-JVS(233)*X(170))/(JVS(230))
  X(73) = (X(73)-JVS(228)*X(170)-JVS(229)*X(180))/(JVS(227))
  X(72) = (X(72)-JVS(225)*X(170)-JVS(226)*X(177))/(JVS(224))
  X(71) = (X(71)-JVS(221)*X(170)-JVS(222)*X(173)-JVS(223)*X(179))/(JVS(220))
  X(70) = (X(70)-JVS(217)*X(134)-JVS(218)*X(169)-JVS(219)*X(170))/(JVS(216))
  X(69) = (X(69)-JVS(214)*X(170)-JVS(215)*X(176))/(JVS(213))
  X(68) = (X(68)-JVS(211)*X(170)-JVS(212)*X(177))/(JVS(210))
  X(67) = (X(67)-JVS(208)*X(170)-JVS(209)*X(177))/(JVS(207))
  X(66) = (X(66)-JVS(205)*X(170)-JVS(206)*X(177))/(JVS(204))
  X(65) = (X(65)-JVS(202)*X(170)-JVS(203)*X(177))/(JVS(201))
  X(64) = (X(64)-JVS(198)*X(94)-JVS(199)*X(170)-JVS(200)*X(181))/(JVS(197))
  X(63) = (X(63)-JVS(194)*X(158)-JVS(195)*X(170)-JVS(196)*X(178))/(JVS(193))
  X(62) = (X(62)-JVS(191)*X(170)-JVS(192)*X(175))/(JVS(190))
  X(61) = (X(61)-JVS(187)*X(139)-JVS(188)*X(169)-JVS(189)*X(170))/(JVS(186))
  X(60) = (X(60)-JVS(183)*X(120)-JVS(184)*X(169)-JVS(185)*X(170))/(JVS(182))
  X(59) = (X(59)-JVS(180)*X(170)-JVS(181)*X(178))/(JVS(179))
  X(58) = (X(58)-JVS(177)*X(167)-JVS(178)*X(179))/(JVS(176))
  X(57) = (X(57)-JVS(174)*X(170)-JVS(175)*X(177))/(JVS(173))
  X(56) = (X(56)-JVS(171)*X(170)-JVS(172)*X(177))/(JVS(170))
  X(55) = (X(55)-JVS(167)*X(164)-JVS(168)*X(169)-JVS(169)*X(170))/(JVS(166))
  X(54) = (X(54)-JVS(164)*X(170)-JVS(165)*X(175))/(JVS(163))
  X(53) = (X(53)-JVS(161)*X(173)-JVS(162)*X(179))/(JVS(160))
  X(52) = (X(52)-JVS(158)*X(170)-JVS(159)*X(171))/(JVS(157))
  X(51) = (X(51)-JVS(155)*X(164)-JVS(156)*X(179))/(JVS(154))
  X(50) = (X(50)-JVS(153)*X(177))/(JVS(152))
  X(49) = (X(49)-JVS(149)*X(53)-JVS(150)*X(177)-JVS(151)*X(179))/(JVS(148))
  X(48) = (X(48)-JVS(147)*X(177))/(JVS(146))
  X(47) = (X(47)-JVS(145)*X(177))/(JVS(144))
  X(46) = (X(46)-JVS(143)*X(177))/(JVS(142))
  X(45) = (X(45)-JVS(141)*X(177))/(JVS(140))
  X(44) = (X(44)-JVS(139)*X(177))/(JVS(138))
  X(43) = (X(43)-JVS(137)*X(177))/(JVS(136))
  X(42) = (X(42)-JVS(135)*X(177))/(JVS(134))
  X(41) = (X(41)-JVS(133)*X(177))/(JVS(132))
  X(40) = (X(40)-JVS(130)*X(99)-JVS(131)*X(179))/(JVS(129))
  X(39) = (X(39)-JVS(127)*X(87)-JVS(128)*X(170))/(JVS(126))
  X(38) = (X(38)-JVS(124)*X(176)-JVS(125)*X(179))/(JVS(123))
  X(37) = (X(37)-JVS(121)*X(136)-JVS(122)*X(179))/(JVS(120))
  X(36) = (X(36)-JVS(119)*X(170))/(JVS(118))
  X(35) = (X(35)-JVS(90)*X(37)-JVS(91)*X(39)-JVS(92)*X(40)-JVS(93)*X(51)-JVS(94)*X(81)-JVS(95)*X(87)-JVS(96)*X(94)&
            &-JVS(97)*X(97)-JVS(98)*X(103)-JVS(99)*X(106)-JVS(100)*X(107)-JVS(101)*X(115)-JVS(102)*X(119)-JVS(103)*X(124)&
            &-JVS(104)*X(125)-JVS(105)*X(126)-JVS(106)*X(128)-JVS(107)*X(145)-JVS(108)*X(149)-JVS(109)*X(156)-JVS(110)&
            &*X(159)-JVS(111)*X(161)-JVS(112)*X(162)-JVS(113)*X(165)-JVS(114)*X(168)-JVS(115)*X(172)-JVS(116)*X(179)&
            &-JVS(117)*X(181))/(JVS(89))
  X(34) = (X(34)-JVS(69)*X(52)-JVS(70)*X(82)-JVS(71)*X(88)-JVS(72)*X(93)-JVS(73)*X(98)-JVS(74)*X(99)-JVS(75)*X(100)&
            &-JVS(76)*X(121)-JVS(77)*X(130)-JVS(78)*X(137)-JVS(79)*X(147)-JVS(80)*X(148)-JVS(81)*X(149)-JVS(82)*X(164)&
            &-JVS(83)*X(166)-JVS(84)*X(167)-JVS(85)*X(168)-JVS(86)*X(169)-JVS(87)*X(170)-JVS(88)*X(173))/(JVS(68))
  X(33) = (X(33)-JVS(67)*X(181))/(JVS(66))
  X(32) = X(32)/JVS(65)
  X(31) = X(31)/JVS(64)
  X(30) = (X(30)-JVS(63)*X(115))/(JVS(62))
  X(29) = (X(29)-JVS(61)*X(106))/(JVS(60))
  X(28) = (X(28)-JVS(59)*X(126))/(JVS(58))
  X(27) = (X(27)-JVS(57)*X(39))/(JVS(56))
  X(26) = (X(26)-JVS(55)*X(87))/(JVS(54))
  X(25) = (X(25)-JVS(53)*X(97))/(JVS(52))
  X(24) = (X(24)-JVS(51)*X(124))/(JVS(50))
  X(23) = (X(23)-JVS(48)*X(106)-JVS(49)*X(170))/(JVS(47))
  X(22) = (X(22)-JVS(46)*X(81))/(JVS(45))
  X(21) = (X(21)-JVS(44)*X(107))/(JVS(43))
  X(20) = (X(20)-JVS(42)*X(172))/(JVS(41))
  X(19) = (X(19)-JVS(40)*X(119))/(JVS(39))
  X(18) = (X(18)-JVS(37)*X(114)-JVS(38)*X(170))/(JVS(36))
  X(17) = (X(17)-JVS(34)*X(62)-JVS(35)*X(170))/(JVS(33))
  X(16) = (X(16)-JVS(32)*X(162))/(JVS(31))
  X(15) = (X(15)-JVS(30)*X(149))/(JVS(29))
  X(14) = (X(14)-JVS(28)*X(161))/(JVS(27))
  X(13) = (X(13)-JVS(26)*X(159))/(JVS(25))
  X(12) = (X(12)-JVS(24)*X(156))/(JVS(23))
  X(11) = (X(11)-JVS(22)*X(37))/(JVS(21))
  X(10) = (X(10)-JVS(20)*X(40))/(JVS(19))
  X(9) = (X(9)-JVS(18)*X(103))/(JVS(17))
  X(8) = (X(8)-JVS(16)*X(51))/(JVS(15))
  X(7) = (X(7)-JVS(14)*X(168))/(JVS(13))
  X(6) = (X(6)-JVS(12)*X(179))/(JVS(11))
  X(5) = (X(5)-JVS(10)*X(94))/(JVS(9))
  X(4) = (X(4)-JVS(8)*X(145))/(JVS(7))
  X(3) = (X(3)-JVS(6)*X(128))/(JVS(5))
  X(2) = (X(2)-JVS(4)*X(165))/(JVS(3))
  X(1) = (X(1)-JVS(2)*X(125))/(JVS(1))
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(3)
  XX(3) = X(3)/JVS(5)
  XX(4) = X(4)/JVS(7)
  XX(5) = X(5)/JVS(9)
  XX(6) = X(6)/JVS(11)
  XX(7) = X(7)/JVS(13)
  XX(8) = X(8)/JVS(15)
  XX(9) = X(9)/JVS(17)
  XX(10) = X(10)/JVS(19)
  XX(11) = X(11)/JVS(21)
  XX(12) = X(12)/JVS(23)
  XX(13) = X(13)/JVS(25)
  XX(14) = X(14)/JVS(27)
  XX(15) = X(15)/JVS(29)
  XX(16) = X(16)/JVS(31)
  XX(17) = X(17)/JVS(33)
  XX(18) = X(18)/JVS(36)
  XX(19) = X(19)/JVS(39)
  XX(20) = X(20)/JVS(41)
  XX(21) = X(21)/JVS(43)
  XX(22) = X(22)/JVS(45)
  XX(23) = X(23)/JVS(47)
  XX(24) = X(24)/JVS(50)
  XX(25) = X(25)/JVS(52)
  XX(26) = X(26)/JVS(54)
  XX(27) = X(27)/JVS(56)
  XX(28) = X(28)/JVS(58)
  XX(29) = X(29)/JVS(60)
  XX(30) = X(30)/JVS(62)
  XX(31) = X(31)/JVS(64)
  XX(32) = X(32)/JVS(65)
  XX(33) = X(33)/JVS(66)
  XX(34) = X(34)/JVS(68)
  XX(35) = X(35)/JVS(89)
  XX(36) = X(36)/JVS(118)
  XX(37) = (X(37)-JVS(22)*XX(11)-JVS(90)*XX(35))/(JVS(120))
  XX(38) = X(38)/JVS(123)
  XX(39) = (X(39)-JVS(57)*XX(27)-JVS(91)*XX(35))/(JVS(126))
  XX(40) = (X(40)-JVS(20)*XX(10)-JVS(92)*XX(35))/(JVS(129))
  XX(41) = X(41)/JVS(132)
  XX(42) = X(42)/JVS(134)
  XX(43) = X(43)/JVS(136)
  XX(44) = X(44)/JVS(138)
  XX(45) = X(45)/JVS(140)
  XX(46) = X(46)/JVS(142)
  XX(47) = X(47)/JVS(144)
  XX(48) = X(48)/JVS(146)
  XX(49) = X(49)/JVS(148)
  XX(50) = X(50)/JVS(152)
  XX(51) = (X(51)-JVS(16)*XX(8)-JVS(93)*XX(35))/(JVS(154))
  XX(52) = (X(52)-JVS(69)*XX(34))/(JVS(157))
  XX(53) = (X(53)-JVS(149)*XX(49))/(JVS(160))
  XX(54) = X(54)/JVS(163)
  XX(55) = X(55)/JVS(166)
  XX(56) = X(56)/JVS(170)
  XX(57) = X(57)/JVS(173)
  XX(58) = X(58)/JVS(176)
  XX(59) = X(59)/JVS(179)
  XX(60) = X(60)/JVS(182)
  XX(61) = X(61)/JVS(186)
  XX(62) = (X(62)-JVS(34)*XX(17))/(JVS(190))
  XX(63) = X(63)/JVS(193)
  XX(64) = X(64)/JVS(197)
  XX(65) = X(65)/JVS(201)
  XX(66) = X(66)/JVS(204)
  XX(67) = X(67)/JVS(207)
  XX(68) = X(68)/JVS(210)
  XX(69) = X(69)/JVS(213)
  XX(70) = X(70)/JVS(216)
  XX(71) = X(71)/JVS(220)
  XX(72) = X(72)/JVS(224)
  XX(73) = X(73)/JVS(227)
  XX(74) = X(74)/JVS(230)
  XX(75) = X(75)/JVS(235)
  XX(76) = X(76)/JVS(241)
  XX(77) = X(77)/JVS(245)
  XX(78) = X(78)/JVS(249)
  XX(79) = X(79)/JVS(258)
  XX(80) = X(80)/JVS(263)
  XX(81) = (X(81)-JVS(46)*XX(22)-JVS(94)*XX(35))/(JVS(273))
  XX(82) = (X(82)-JVS(70)*XX(34))/(JVS(280))
  XX(83) = X(83)/JVS(287)
  XX(84) = X(84)/JVS(291)
  XX(85) = X(85)/JVS(295)
  XX(86) = X(86)/JVS(301)
  XX(87) = (X(87)-JVS(55)*XX(26)-JVS(95)*XX(35)-JVS(127)*XX(39))/(JVS(306))
  XX(88) = (X(88)-JVS(71)*XX(34))/(JVS(310))
  XX(89) = X(89)/JVS(315)
  XX(90) = X(90)/JVS(319)
  XX(91) = X(91)/JVS(323)
  XX(92) = X(92)/JVS(328)
  XX(93) = (X(93)-JVS(72)*XX(34))/(JVS(334))
  XX(94) = (X(94)-JVS(10)*XX(5)-JVS(96)*XX(35)-JVS(198)*XX(64))/(JVS(340))
  XX(95) = X(95)/JVS(345)
  XX(96) = X(96)/JVS(351)
  XX(97) = (X(97)-JVS(53)*XX(25)-JVS(97)*XX(35))/(JVS(357))
  XX(98) = (X(98)-JVS(73)*XX(34))/(JVS(364))
  XX(99) = (X(99)-JVS(74)*XX(34)-JVS(130)*XX(40))/(JVS(370))
  XX(100) = (X(100)-JVS(75)*XX(34)-JVS(296)*XX(85))/(JVS(377))
  XX(101) = X(101)/JVS(384)
  XX(102) = (X(102)-JVS(297)*XX(85))/(JVS(399))
  XX(103) = (X(103)-JVS(18)*XX(9)-JVS(98)*XX(35))/(JVS(404))
  XX(104) = (X(104)-JVS(264)*XX(80))/(JVS(410))
  XX(105) = (X(105)-JVS(265)*XX(80))/(JVS(417))
  XX(106) = (X(106)-JVS(48)*XX(23)-JVS(61)*XX(29)-JVS(99)*XX(35))/(JVS(425))
  XX(107) = (X(107)-JVS(44)*XX(21)-JVS(100)*XX(35)-JVS(250)*XX(78)-JVS(274)*XX(81))/(JVS(433))
  XX(108) = X(108)/JVS(439)
  XX(109) = (X(109)-JVS(266)*XX(80))/(JVS(450))
  XX(110) = X(110)/JVS(458)
  XX(111) = (X(111)-JVS(346)*XX(95))/(JVS(468))
  XX(112) = (X(112)-JVS(267)*XX(80))/(JVS(474))
  XX(113) = (X(113)-JVS(268)*XX(80))/(JVS(483))
  XX(114) = (X(114)-JVS(37)*XX(18)-JVS(411)*XX(104)-JVS(475)*XX(112))/(JVS(491))
  XX(115) = (X(115)-JVS(63)*XX(30)-JVS(101)*XX(35))/(JVS(496))
  XX(116) = (X(116)-JVS(269)*XX(80))/(JVS(507))
  XX(117) = (X(117)-JVS(418)*XX(105)-JVS(476)*XX(112))/(JVS(515))
  XX(118) = (X(118)-JVS(347)*XX(95))/(JVS(520))
  XX(119) = (X(119)-JVS(40)*XX(19)-JVS(102)*XX(35)-JVS(251)*XX(78)-JVS(275)*XX(81))/(JVS(528))
  XX(120) = (X(120)-JVS(183)*XX(60)-JVS(385)*XX(101))/(JVS(540))
  XX(121) = (X(121)-JVS(76)*XX(34)-JVS(386)*XX(101))/(JVS(550))
  XX(122) = X(122)/JVS(561)
  XX(123) = (X(123)-JVS(440)*XX(108))/(JVS(574))
  XX(124) = (X(124)-JVS(51)*XX(24)-JVS(103)*XX(35)-JVS(281)*XX(82)-JVS(497)*XX(115))/(JVS(582))
  XX(125) = (X(125)-JVS(2)*XX(1)-JVS(104)*XX(35))/(JVS(590))
  XX(126) = (X(126)-JVS(59)*XX(28)-JVS(105)*XX(35)-JVS(371)*XX(99))/(JVS(601))
  XX(127) = (X(127)-JVS(292)*XX(84)-JVS(387)*XX(101))/(JVS(612))
  XX(128) = (X(128)-JVS(6)*XX(3)-JVS(106)*XX(35))/(JVS(629))
  XX(129) = (X(129)-JVS(259)*XX(79)-JVS(405)*XX(103))/(JVS(644))
  XX(130) = (X(130)-JVS(77)*XX(34)-JVS(352)*XX(96)-JVS(498)*XX(115))/(JVS(651))
  XX(131) = (X(131)-JVS(288)*XX(83)-JVS(388)*XX(101)-JVS(499)*XX(115))/(JVS(660))
  XX(132) = (X(132)-JVS(311)*XX(88)-JVS(389)*XX(101)-JVS(602)*XX(126))/(JVS(670))
  XX(133) = (X(133)-JVS(320)*XX(90)-JVS(390)*XX(101)-JVS(426)*XX(106))/(JVS(680))
  XX(134) = (X(134)-JVS(217)*XX(70))/(JVS(691))
  XX(135) = (X(135)-JVS(302)*XX(86)-JVS(391)*XX(101))/(JVS(704))
  XX(136) = (X(136)-JVS(121)*XX(37)-JVS(260)*XX(79)-JVS(692)*XX(134))/(JVS(715))
  XX(137) = (X(137)-JVS(78)*XX(34)-JVS(562)*XX(122))/(JVS(735))
  XX(138) = (X(138)-JVS(324)*XX(91)-JVS(329)*XX(92)-JVS(335)*XX(93)-JVS(378)*XX(100)-JVS(392)*XX(101)-JVS(563)*XX(122)&
              &-JVS(736)*XX(137))/(JVS(754))
  XX(139) = (X(139)-JVS(187)*XX(61)-JVS(393)*XX(101)-JVS(591)*XX(125))/(JVS(763))
  XX(140) = (X(140)-JVS(252)*XX(78)-JVS(459)*XX(110))/(JVS(772))
  XX(141) = (X(141)-JVS(394)*XX(101))/(JVS(783))
  XX(142) = (X(142)-JVS(253)*XX(78)-JVS(460)*XX(110))/(JVS(800))
  XX(143) = (X(143)-JVS(303)*XX(86))/(JVS(818))
  XX(144) = (X(144)-JVS(469)*XX(111)-JVS(521)*XX(118)-JVS(564)*XX(122)-JVS(645)*XX(129)-JVS(716)*XX(136))/(JVS(829))
  XX(145) = (X(145)-JVS(8)*XX(4)-JVS(107)*XX(35))/(JVS(850))
  XX(146) = (X(146)-JVS(270)*XX(80)-JVS(312)*XX(88)-JVS(630)*XX(128)-JVS(671)*XX(132))/(JVS(883))
  XX(147) = (X(147)-JVS(79)*XX(34)-JVS(231)*XX(74)-JVS(406)*XX(103)-JVS(551)*XX(121)-JVS(851)*XX(145))/(JVS(895))
  XX(148) = (X(148)-JVS(80)*XX(34)-JVS(307)*XX(87)-JVS(358)*XX(97)-JVS(365)*XX(98)-JVS(395)*XX(101)-JVS(400)*XX(102)&
              &-JVS(427)*XX(106)-JVS(565)*XX(122)-JVS(583)*XX(124)-JVS(603)*XX(126)-JVS(737)*XX(137)-JVS(852)*XX(145))&
              &/(JVS(908))
  XX(149) = (X(149)-JVS(30)*XX(15)-JVS(81)*XX(34)-JVS(108)*XX(35))/(JVS(937))
  XX(150) = (X(150)-JVS(348)*XX(95)-JVS(584)*XX(124)-JVS(738)*XX(137)-JVS(830)*XX(144)-JVS(853)*XX(145)-JVS(896)*XX(147)&
              &-JVS(938)*XX(149))/(JVS(963))
  XX(151) = (X(151)-JVS(451)*XX(109)-JVS(484)*XX(113)-JVS(631)*XX(128)-JVS(739)*XX(137)-JVS(755)*XX(138)-JVS(854)&
              &*XX(145)-JVS(939)*XX(149))/(JVS(976))
  XX(152) = (X(152)-JVS(855)*XX(145))/(JVS(1008))
  XX(153) = (X(153)-JVS(353)*XX(96)-JVS(428)*XX(106)-JVS(604)*XX(126)-JVS(740)*XX(137)-JVS(784)*XX(141)-JVS(856)*XX(145)&
              &-JVS(940)*XX(149)-JVS(1009)*XX(152))/(JVS(1031))
  XX(154) = (X(154)-JVS(282)*XX(82)-JVS(354)*XX(96)-JVS(500)*XX(115)-JVS(605)*XX(126)-JVS(741)*XX(137)-JVS(785)*XX(141)&
              &-JVS(857)*XX(145)-JVS(941)*XX(149)-JVS(1010)*XX(152)-JVS(1032)*XX(153))/(JVS(1047))
  XX(155) = (X(155)-JVS(298)*XX(85)-JVS(396)*XX(101)-JVS(541)*XX(120)-JVS(592)*XX(125)-JVS(693)*XX(134)-JVS(764)*XX(139)&
              &-JVS(819)*XX(143)-JVS(942)*XX(149)-JVS(1011)*XX(152))/(JVS(1066))
  XX(156) = (X(156)-JVS(24)*XX(12)-JVS(109)*XX(35)-JVS(542)*XX(120)-JVS(593)*XX(125)-JVS(694)*XX(134)-JVS(765)*XX(139)&
              &-JVS(786)*XX(141)-JVS(820)*XX(143)-JVS(943)*XX(149)-JVS(1012)*XX(152)-JVS(1067)*XX(155))/(JVS(1089))
  XX(157) = (X(157)-JVS(695)*XX(134)-JVS(717)*XX(136)-JVS(858)*XX(145))/(JVS(1132))
  XX(158) = (X(158)-JVS(194)*XX(63)-JVS(236)*XX(75)-JVS(254)*XX(78)-JVS(276)*XX(81)-JVS(434)*XX(107)-JVS(461)*XX(110)&
              &-JVS(529)*XX(119)-JVS(801)*XX(142)-JVS(859)*XX(145))/(JVS(1155))
  XX(159) = (X(159)-JVS(26)*XX(13)-JVS(110)*XX(35)-JVS(477)*XX(112)-JVS(508)*XX(116)-JVS(516)*XX(117)-JVS(575)*XX(123)&
              &-JVS(613)*XX(127)-JVS(632)*XX(128)-JVS(661)*XX(131)-JVS(681)*XX(133)-JVS(718)*XX(136)-JVS(742)*XX(137)&
              &-JVS(860)*XX(145)-JVS(944)*XX(149)-JVS(1013)*XX(152)-JVS(1133)*XX(157))/(JVS(1174))
  XX(160) = (X(160)-JVS(696)*XX(134)-JVS(705)*XX(135)-JVS(719)*XX(136)-JVS(821)*XX(143)-JVS(861)*XX(145)-JVS(945)&
              &*XX(149)-JVS(1014)*XX(152)-JVS(1090)*XX(156)-JVS(1134)*XX(157))/(JVS(1207))
  XX(161) = (X(161)-JVS(28)*XX(14)-JVS(111)*XX(35)-JVS(478)*XX(112)-JVS(485)*XX(113)-JVS(633)*XX(128)-JVS(652)*XX(130)&
              &-JVS(672)*XX(132)-JVS(787)*XX(141)-JVS(862)*XX(145)-JVS(897)*XX(147)-JVS(946)*XX(149)-JVS(1015)*XX(152)&
              &-JVS(1033)*XX(153)-JVS(1048)*XX(154)-JVS(1068)*XX(155)-JVS(1091)*XX(156)-JVS(1135)*XX(157)-JVS(1208)*XX(160))&
              &/(JVS(1225))
  XX(162) = (X(162)-JVS(32)*XX(16)-JVS(112)*XX(35)-JVS(576)*XX(123)-JVS(863)*XX(145))/(JVS(1258))
  XX(163) = (X(163)-JVS(271)*XX(80)-JVS(412)*XX(104)-JVS(419)*XX(105)-JVS(452)*XX(109)-JVS(479)*XX(112)-JVS(486)*XX(113)&
              &-JVS(509)*XX(116)-JVS(634)*XX(128)-JVS(743)*XX(137)-JVS(864)*XX(145)-JVS(884)*XX(146)-JVS(947)*XX(149)&
              &-JVS(1016)*XX(152)-JVS(1136)*XX(157)-JVS(1175)*XX(159)-JVS(1209)*XX(160)-JVS(1226)*XX(161)-JVS(1259)*XX(162))&
              &/(JVS(1285))
  XX(164) = (X(164)-JVS(82)*XX(34)-JVS(155)*XX(51)-JVS(167)*XX(55)-JVS(330)*XX(92)-JVS(336)*XX(93)-JVS(379)*XX(100)&
              &-JVS(401)*XX(102)-JVS(501)*XX(115)-JVS(543)*XX(120)-JVS(552)*XX(121)-JVS(566)*XX(122)-JVS(594)*XX(125)&
              &-JVS(614)*XX(127)-JVS(653)*XX(130)-JVS(662)*XX(131)-JVS(673)*XX(132)-JVS(682)*XX(133)-JVS(697)*XX(134)&
              &-JVS(706)*XX(135)-JVS(720)*XX(136)-JVS(744)*XX(137)-JVS(756)*XX(138)-JVS(766)*XX(139)-JVS(788)*XX(141)&
              &-JVS(822)*XX(143)-JVS(831)*XX(144)-JVS(865)*XX(145)-JVS(898)*XX(147)-JVS(909)*XX(148)-JVS(948)*XX(149)&
              &-JVS(964)*XX(150)-JVS(977)*XX(151)-JVS(1017)*XX(152)-JVS(1034)*XX(153)-JVS(1049)*XX(154)-JVS(1069)*XX(155)&
              &-JVS(1092)*XX(156)-JVS(1137)*XX(157)-JVS(1176)*XX(159)-JVS(1210)*XX(160)-JVS(1227)*XX(161)-JVS(1260)*XX(162)&
              &-JVS(1286)*XX(163))/(JVS(1339))
  XX(165) = (X(165)-JVS(4)*XX(2)-JVS(113)*XX(35)-JVS(441)*XX(108)-JVS(866)*XX(145))/(JVS(1409))
  XX(166) = (X(166)-JVS(83)*XX(34)-JVS(413)*XX(104)-JVS(420)*XX(105)-JVS(453)*XX(109)-JVS(487)*XX(113)-JVS(510)*XX(116)&
              &-JVS(635)*XX(128)-JVS(745)*XX(137)-JVS(867)*XX(145)-JVS(885)*XX(146)-JVS(949)*XX(149)-JVS(1018)*XX(152)&
              &-JVS(1138)*XX(157)-JVS(1177)*XX(159)-JVS(1211)*XX(160)-JVS(1228)*XX(161)-JVS(1261)*XX(162)-JVS(1287)*XX(163)&
              &-JVS(1340)*XX(164)-JVS(1410)*XX(165))/(JVS(1471))
  XX(167) = (X(167)-JVS(84)*XX(34)-JVS(177)*XX(58)-JVS(237)*XX(75)-JVS(242)*XX(76)-JVS(397)*XX(101)-JVS(462)*XX(110)&
              &-JVS(470)*XX(111)-JVS(502)*XX(115)-JVS(522)*XX(118)-JVS(544)*XX(120)-JVS(553)*XX(121)-JVS(567)*XX(122)&
              &-JVS(585)*XX(124)-JVS(595)*XX(125)-JVS(615)*XX(127)-JVS(654)*XX(130)-JVS(663)*XX(131)-JVS(674)*XX(132)&
              &-JVS(683)*XX(133)-JVS(698)*XX(134)-JVS(707)*XX(135)-JVS(721)*XX(136)-JVS(746)*XX(137)-JVS(757)*XX(138)&
              &-JVS(767)*XX(139)-JVS(789)*XX(141)-JVS(802)*XX(142)-JVS(823)*XX(143)-JVS(832)*XX(144)-JVS(868)*XX(145)&
              &-JVS(899)*XX(147)-JVS(910)*XX(148)-JVS(950)*XX(149)-JVS(965)*XX(150)-JVS(978)*XX(151)-JVS(1019)*XX(152)&
              &-JVS(1035)*XX(153)-JVS(1050)*XX(154)-JVS(1070)*XX(155)-JVS(1093)*XX(156)-JVS(1139)*XX(157)-JVS(1178)*XX(159)&
              &-JVS(1212)*XX(160)-JVS(1229)*XX(161)-JVS(1262)*XX(162)-JVS(1288)*XX(163)-JVS(1341)*XX(164)-JVS(1411)*XX(165)&
              &-JVS(1472)*XX(166))/(JVS(1533))
  XX(168) = (X(168)-JVS(14)*XX(7)-JVS(85)*XX(34)-JVS(114)*XX(35)-JVS(283)*XX(82)-JVS(337)*XX(93)-JVS(359)*XX(97)&
              &-JVS(380)*XX(100)-JVS(407)*XX(103)-JVS(414)*XX(104)-JVS(421)*XX(105)-JVS(429)*XX(106)-JVS(442)*XX(108)&
              &-JVS(454)*XX(109)-JVS(480)*XX(112)-JVS(488)*XX(113)-JVS(492)*XX(114)-JVS(503)*XX(115)-JVS(511)*XX(116)&
              &-JVS(517)*XX(117)-JVS(568)*XX(122)-JVS(577)*XX(123)-JVS(586)*XX(124)-JVS(606)*XX(126)-JVS(616)*XX(127)&
              &-JVS(636)*XX(128)-JVS(664)*XX(131)-JVS(684)*XX(133)-JVS(747)*XX(137)-JVS(833)*XX(144)-JVS(869)*XX(145)&
              &-JVS(886)*XX(146)-JVS(900)*XX(147)-JVS(911)*XX(148)-JVS(951)*XX(149)-JVS(966)*XX(150)-JVS(979)*XX(151)&
              &-JVS(1020)*XX(152)-JVS(1036)*XX(153)-JVS(1051)*XX(154)-JVS(1071)*XX(155)-JVS(1094)*XX(156)-JVS(1140)*XX(157)&
              &-JVS(1156)*XX(158)-JVS(1179)*XX(159)-JVS(1213)*XX(160)-JVS(1230)*XX(161)-JVS(1263)*XX(162)-JVS(1289)*XX(163)&
              &-JVS(1342)*XX(164)-JVS(1412)*XX(165)-JVS(1473)*XX(166)-JVS(1534)*XX(167))/(JVS(1571))
  XX(169) = (X(169)-JVS(86)*XX(34)-JVS(168)*XX(55)-JVS(184)*XX(60)-JVS(188)*XX(61)-JVS(218)*XX(70)-JVS(232)*XX(74)&
              &-JVS(243)*XX(76)-JVS(246)*XX(77)-JVS(261)*XX(79)-JVS(284)*XX(82)-JVS(289)*XX(83)-JVS(293)*XX(84)-JVS(299)&
              &*XX(85)-JVS(304)*XX(86)-JVS(308)*XX(87)-JVS(313)*XX(88)-JVS(321)*XX(90)-JVS(325)*XX(91)-JVS(331)*XX(92)&
              &-JVS(349)*XX(95)-JVS(355)*XX(96)-JVS(366)*XX(98)-JVS(372)*XX(99)-JVS(381)*XX(100)-JVS(402)*XX(102)-JVS(430)&
              &*XX(106)-JVS(443)*XX(108)-JVS(471)*XX(111)-JVS(504)*XX(115)-JVS(523)*XX(118)-JVS(530)*XX(119)-JVS(545)&
              &*XX(120)-JVS(554)*XX(121)-JVS(569)*XX(122)-JVS(596)*XX(125)-JVS(607)*XX(126)-JVS(617)*XX(127)-JVS(637)&
              &*XX(128)-JVS(646)*XX(129)-JVS(655)*XX(130)-JVS(665)*XX(131)-JVS(675)*XX(132)-JVS(685)*XX(133)-JVS(699)&
              &*XX(134)-JVS(708)*XX(135)-JVS(722)*XX(136)-JVS(748)*XX(137)-JVS(758)*XX(138)-JVS(768)*XX(139)-JVS(790)&
              &*XX(141)-JVS(803)*XX(142)-JVS(824)*XX(143)-JVS(870)*XX(145)-JVS(901)*XX(147)-JVS(912)*XX(148)-JVS(952)&
              &*XX(149)-JVS(967)*XX(150)-JVS(980)*XX(151)-JVS(1021)*XX(152)-JVS(1037)*XX(153)-JVS(1052)*XX(154)-JVS(1072)&
              &*XX(155)-JVS(1095)*XX(156)-JVS(1141)*XX(157)-JVS(1157)*XX(158)-JVS(1180)*XX(159)-JVS(1214)*XX(160)-JVS(1231)&
              &*XX(161)-JVS(1264)*XX(162)-JVS(1290)*XX(163)-JVS(1343)*XX(164)-JVS(1413)*XX(165)-JVS(1474)*XX(166)-JVS(1535)&
              &*XX(167)-JVS(1572)*XX(168))/(JVS(1660))
  XX(170) = (X(170)-JVS(35)*XX(17)-JVS(38)*XX(18)-JVS(49)*XX(23)-JVS(87)*XX(34)-JVS(119)*XX(36)-JVS(128)*XX(39)-JVS(158)&
              &*XX(52)-JVS(164)*XX(54)-JVS(169)*XX(55)-JVS(171)*XX(56)-JVS(174)*XX(57)-JVS(180)*XX(59)-JVS(185)*XX(60)&
              &-JVS(189)*XX(61)-JVS(191)*XX(62)-JVS(195)*XX(63)-JVS(199)*XX(64)-JVS(202)*XX(65)-JVS(205)*XX(66)-JVS(208)&
              &*XX(67)-JVS(211)*XX(68)-JVS(214)*XX(69)-JVS(219)*XX(70)-JVS(221)*XX(71)-JVS(225)*XX(72)-JVS(228)*XX(73)&
              &-JVS(233)*XX(74)-JVS(238)*XX(75)-JVS(244)*XX(76)-JVS(247)*XX(77)-JVS(262)*XX(79)-JVS(272)*XX(80)-JVS(277)&
              &*XX(81)-JVS(285)*XX(82)-JVS(290)*XX(83)-JVS(294)*XX(84)-JVS(300)*XX(85)-JVS(305)*XX(86)-JVS(309)*XX(87)&
              &-JVS(314)*XX(88)-JVS(316)*XX(89)-JVS(322)*XX(90)-JVS(326)*XX(91)-JVS(332)*XX(92)-JVS(338)*XX(93)-JVS(350)&
              &*XX(95)-JVS(356)*XX(96)-JVS(360)*XX(97)-JVS(367)*XX(98)-JVS(373)*XX(99)-JVS(382)*XX(100)-JVS(398)*XX(101)&
              &-JVS(408)*XX(103)-JVS(431)*XX(106)-JVS(444)*XX(108)-JVS(463)*XX(110)-JVS(472)*XX(111)-JVS(493)*XX(114)&
              &-JVS(505)*XX(115)-JVS(518)*XX(117)-JVS(531)*XX(119)-JVS(546)*XX(120)-JVS(555)*XX(121)-JVS(570)*XX(122)&
              &-JVS(578)*XX(123)-JVS(587)*XX(124)-JVS(597)*XX(125)-JVS(608)*XX(126)-JVS(618)*XX(127)-JVS(638)*XX(128)&
              &-JVS(647)*XX(129)-JVS(666)*XX(131)-JVS(676)*XX(132)-JVS(686)*XX(133)-JVS(700)*XX(134)-JVS(709)*XX(135)&
              &-JVS(723)*XX(136)-JVS(749)*XX(137)-JVS(759)*XX(138)-JVS(769)*XX(139)-JVS(773)*XX(140)-JVS(791)*XX(141)&
              &-JVS(804)*XX(142)-JVS(825)*XX(143)-JVS(834)*XX(144)-JVS(871)*XX(145)-JVS(887)*XX(146)-JVS(902)*XX(147)&
              &-JVS(913)*XX(148)-JVS(953)*XX(149)-JVS(968)*XX(150)-JVS(981)*XX(151)-JVS(1022)*XX(152)-JVS(1038)*XX(153)&
              &-JVS(1053)*XX(154)-JVS(1073)*XX(155)-JVS(1096)*XX(156)-JVS(1142)*XX(157)-JVS(1158)*XX(158)-JVS(1181)*XX(159)&
              &-JVS(1215)*XX(160)-JVS(1232)*XX(161)-JVS(1265)*XX(162)-JVS(1291)*XX(163)-JVS(1344)*XX(164)-JVS(1414)*XX(165)&
              &-JVS(1475)*XX(166)-JVS(1536)*XX(167)-JVS(1573)*XX(168)-JVS(1661)*XX(169))/(JVS(1789))
  XX(171) = (X(171)-JVS(159)*XX(52)-JVS(445)*XX(108)-JVS(532)*XX(119)-JVS(639)*XX(128)-JVS(774)*XX(140)-JVS(805)*XX(142)&
              &-JVS(872)*XX(145)-JVS(1159)*XX(158)-JVS(1292)*XX(163)-JVS(1345)*XX(164)-JVS(1415)*XX(165)-JVS(1476)*XX(166)&
              &-JVS(1537)*XX(167)-JVS(1574)*XX(168)-JVS(1662)*XX(169)-JVS(1790)*XX(170))/(JVS(1840))
  XX(172) = (X(172)-JVS(42)*XX(20)-JVS(115)*XX(35)-JVS(255)*XX(78)-JVS(278)*XX(81)-JVS(446)*XX(108)-JVS(533)*XX(119)&
              &-JVS(775)*XX(140)-JVS(806)*XX(142)-JVS(873)*XX(145)-JVS(1160)*XX(158)-JVS(1575)*XX(168)-JVS(1663)*XX(169)&
              &-JVS(1791)*XX(170)-JVS(1841)*XX(171))/(JVS(1872))
  XX(173) = (X(173)-JVS(88)*XX(34)-JVS(161)*XX(53)-JVS(222)*XX(71)-JVS(286)*XX(82)-JVS(333)*XX(92)-JVS(339)*XX(93)&
              &-JVS(361)*XX(97)-JVS(368)*XX(98)-JVS(374)*XX(99)-JVS(383)*XX(100)-JVS(403)*XX(102)-JVS(415)*XX(104)-JVS(422)&
              &*XX(105)-JVS(432)*XX(106)-JVS(455)*XX(109)-JVS(473)*XX(111)-JVS(481)*XX(112)-JVS(489)*XX(113)-JVS(506)&
              &*XX(115)-JVS(512)*XX(116)-JVS(524)*XX(118)-JVS(547)*XX(120)-JVS(556)*XX(121)-JVS(571)*XX(122)-JVS(588)&
              &*XX(124)-JVS(598)*XX(125)-JVS(609)*XX(126)-JVS(619)*XX(127)-JVS(640)*XX(128)-JVS(648)*XX(129)-JVS(656)&
              &*XX(130)-JVS(667)*XX(131)-JVS(677)*XX(132)-JVS(687)*XX(133)-JVS(701)*XX(134)-JVS(710)*XX(135)-JVS(724)&
              &*XX(136)-JVS(750)*XX(137)-JVS(760)*XX(138)-JVS(770)*XX(139)-JVS(792)*XX(141)-JVS(826)*XX(143)-JVS(835)&
              &*XX(144)-JVS(874)*XX(145)-JVS(888)*XX(146)-JVS(903)*XX(147)-JVS(914)*XX(148)-JVS(954)*XX(149)-JVS(969)&
              &*XX(150)-JVS(982)*XX(151)-JVS(1023)*XX(152)-JVS(1039)*XX(153)-JVS(1054)*XX(154)-JVS(1074)*XX(155)-JVS(1097)&
              &*XX(156)-JVS(1143)*XX(157)-JVS(1161)*XX(158)-JVS(1182)*XX(159)-JVS(1216)*XX(160)-JVS(1233)*XX(161)-JVS(1266)&
              &*XX(162)-JVS(1293)*XX(163)-JVS(1346)*XX(164)-JVS(1416)*XX(165)-JVS(1477)*XX(166)-JVS(1538)*XX(167)-JVS(1576)&
              &*XX(168)-JVS(1664)*XX(169)-JVS(1792)*XX(170)-JVS(1842)*XX(171)-JVS(1873)*XX(172))/(JVS(1939))
  XX(174) = (X(174)-JVS(341)*XX(94)-JVS(435)*XX(107)-JVS(534)*XX(119)-JVS(776)*XX(140)-JVS(807)*XX(142)-JVS(875)*XX(145)&
              &-JVS(1162)*XX(158)-JVS(1665)*XX(169)-JVS(1793)*XX(170)-JVS(1843)*XX(171)-JVS(1874)*XX(172)-JVS(1940)*XX(173))&
              &/(JVS(2000))
  XX(175) = (X(175)-JVS(165)*XX(54)-JVS(192)*XX(62)-JVS(317)*XX(89)-JVS(342)*XX(94)-JVS(494)*XX(114)-JVS(519)*XX(117)&
              &-JVS(525)*XX(118)-JVS(572)*XX(122)-JVS(579)*XX(123)-JVS(620)*XX(127)-JVS(641)*XX(128)-JVS(649)*XX(129)&
              &-JVS(657)*XX(130)-JVS(668)*XX(131)-JVS(688)*XX(133)-JVS(702)*XX(134)-JVS(711)*XX(135)-JVS(725)*XX(136)&
              &-JVS(751)*XX(137)-JVS(793)*XX(141)-JVS(808)*XX(142)-JVS(827)*XX(143)-JVS(836)*XX(144)-JVS(876)*XX(145)&
              &-JVS(889)*XX(146)-JVS(904)*XX(147)-JVS(915)*XX(148)-JVS(955)*XX(149)-JVS(970)*XX(150)-JVS(983)*XX(151)&
              &-JVS(1024)*XX(152)-JVS(1040)*XX(153)-JVS(1055)*XX(154)-JVS(1075)*XX(155)-JVS(1098)*XX(156)-JVS(1144)*XX(157)&
              &-JVS(1163)*XX(158)-JVS(1183)*XX(159)-JVS(1217)*XX(160)-JVS(1234)*XX(161)-JVS(1267)*XX(162)-JVS(1294)*XX(163)&
              &-JVS(1347)*XX(164)-JVS(1417)*XX(165)-JVS(1478)*XX(166)-JVS(1539)*XX(167)-JVS(1577)*XX(168)-JVS(1666)*XX(169)&
              &-JVS(1794)*XX(170)-JVS(1844)*XX(171)-JVS(1875)*XX(172)-JVS(1941)*XX(173)-JVS(2001)*XX(174))/(JVS(2066))
  XX(176) = (X(176)-JVS(124)*XX(38)-JVS(215)*XX(69)-JVS(279)*XX(81)-JVS(318)*XX(89)-JVS(436)*XX(107)-JVS(535)*XX(119)&
              &-JVS(548)*XX(120)-JVS(599)*XX(125)-JVS(703)*XX(134)-JVS(771)*XX(139)-JVS(828)*XX(143)-JVS(877)*XX(145)&
              &-JVS(956)*XX(149)-JVS(1025)*XX(152)-JVS(1099)*XX(156)-JVS(1145)*XX(157)-JVS(1164)*XX(158)-JVS(1218)*XX(160)&
              &-JVS(1268)*XX(162)-JVS(1348)*XX(164)-JVS(1418)*XX(165)-JVS(1479)*XX(166)-JVS(1540)*XX(167)-JVS(1578)*XX(168)&
              &-JVS(1667)*XX(169)-JVS(1795)*XX(170)-JVS(1845)*XX(171)-JVS(1876)*XX(172)-JVS(1942)*XX(173)-JVS(2002)*XX(174)&
              &-JVS(2067)*XX(175))/(JVS(2109))
  XX(177) = (X(177)-JVS(133)*XX(41)-JVS(135)*XX(42)-JVS(137)*XX(43)-JVS(139)*XX(44)-JVS(141)*XX(45)-JVS(143)*XX(46)&
              &-JVS(145)*XX(47)-JVS(147)*XX(48)-JVS(150)*XX(49)-JVS(153)*XX(50)-JVS(172)*XX(56)-JVS(175)*XX(57)-JVS(203)&
              &*XX(65)-JVS(206)*XX(66)-JVS(209)*XX(67)-JVS(212)*XX(68)-JVS(226)*XX(72)-JVS(447)*XX(108)-JVS(464)*XX(110)&
              &-JVS(580)*XX(123)-JVS(809)*XX(142)-JVS(1165)*XX(158)-JVS(1419)*XX(165)-JVS(1480)*XX(166)-JVS(1541)*XX(167)&
              &-JVS(1579)*XX(168)-JVS(1668)*XX(169)-JVS(1796)*XX(170)-JVS(1846)*XX(171)-JVS(1877)*XX(172)-JVS(1943)*XX(173)&
              &-JVS(2003)*XX(174)-JVS(2068)*XX(175)-JVS(2110)*XX(176))/(JVS(2153))
  XX(178) = (X(178)-JVS(181)*XX(59)-JVS(196)*XX(63)-JVS(239)*XX(75)-JVS(256)*XX(78)-JVS(465)*XX(110)-JVS(777)*XX(140)&
              &-JVS(810)*XX(142)-JVS(878)*XX(145)-JVS(1166)*XX(158)-JVS(1420)*XX(165)-JVS(1481)*XX(166)-JVS(1542)*XX(167)&
              &-JVS(1580)*XX(168)-JVS(1669)*XX(169)-JVS(1797)*XX(170)-JVS(1847)*XX(171)-JVS(1878)*XX(172)-JVS(1944)*XX(173)&
              &-JVS(2004)*XX(174)-JVS(2069)*XX(175)-JVS(2111)*XX(176)-JVS(2154)*XX(177))/(JVS(2187))
  XX(179) = (X(179)-JVS(12)*XX(6)-JVS(116)*XX(35)-JVS(122)*XX(37)-JVS(125)*XX(38)-JVS(131)*XX(40)-JVS(151)*XX(49)&
              &-JVS(156)*XX(51)-JVS(162)*XX(53)-JVS(178)*XX(58)-JVS(223)*XX(71)-JVS(248)*XX(77)-JVS(343)*XX(94)-JVS(375)&
              &*XX(99)-JVS(409)*XX(103)-JVS(416)*XX(104)-JVS(423)*XX(105)-JVS(437)*XX(107)-JVS(456)*XX(109)-JVS(482)*XX(112)&
              &-JVS(490)*XX(113)-JVS(513)*XX(116)-JVS(536)*XX(119)-JVS(642)*XX(128)-JVS(650)*XX(129)-JVS(726)*XX(136)&
              &-JVS(752)*XX(137)-JVS(778)*XX(140)-JVS(811)*XX(142)-JVS(879)*XX(145)-JVS(890)*XX(146)-JVS(905)*XX(147)&
              &-JVS(957)*XX(149)-JVS(1026)*XX(152)-JVS(1100)*XX(156)-JVS(1146)*XX(157)-JVS(1167)*XX(158)-JVS(1184)*XX(159)&
              &-JVS(1219)*XX(160)-JVS(1235)*XX(161)-JVS(1269)*XX(162)-JVS(1295)*XX(163)-JVS(1349)*XX(164)-JVS(1421)*XX(165)&
              &-JVS(1482)*XX(166)-JVS(1543)*XX(167)-JVS(1581)*XX(168)-JVS(1670)*XX(169)-JVS(1798)*XX(170)-JVS(1848)*XX(171)&
              &-JVS(1879)*XX(172)-JVS(1945)*XX(173)-JVS(2005)*XX(174)-JVS(2070)*XX(175)-JVS(2112)*XX(176)-JVS(2155)*XX(177)&
              &-JVS(2188)*XX(178))/(JVS(2276))
  XX(180) = (X(180)-JVS(229)*XX(73)-JVS(240)*XX(75)-JVS(448)*XX(108)-JVS(466)*XX(110)-JVS(581)*XX(123)-JVS(643)*XX(128)&
              &-JVS(779)*XX(140)-JVS(812)*XX(142)-JVS(880)*XX(145)-JVS(1422)*XX(165)-JVS(1483)*XX(166)-JVS(1544)*XX(167)&
              &-JVS(1582)*XX(168)-JVS(1671)*XX(169)-JVS(1799)*XX(170)-JVS(1849)*XX(171)-JVS(1880)*XX(172)-JVS(1946)*XX(173)&
              &-JVS(2006)*XX(174)-JVS(2071)*XX(175)-JVS(2113)*XX(176)-JVS(2156)*XX(177)-JVS(2189)*XX(178)-JVS(2277)*XX(179))&
              &/(JVS(2327))
  XX(181) = (X(181)-JVS(67)*XX(33)-JVS(117)*XX(35)-JVS(200)*XX(64)-JVS(257)*XX(78)-JVS(344)*XX(94)-JVS(438)*XX(107)&
              &-JVS(449)*XX(108)-JVS(467)*XX(110)-JVS(537)*XX(119)-JVS(780)*XX(140)-JVS(813)*XX(142)-JVS(881)*XX(145)&
              &-JVS(1168)*XX(158)-JVS(1583)*XX(168)-JVS(1672)*XX(169)-JVS(1800)*XX(170)-JVS(1850)*XX(171)-JVS(1881)*XX(172)&
              &-JVS(1947)*XX(173)-JVS(2007)*XX(174)-JVS(2072)*XX(175)-JVS(2114)*XX(176)-JVS(2157)*XX(177)-JVS(2190)*XX(178)&
              &-JVS(2278)*XX(179)-JVS(2328)*XX(180))/(JVS(2361))
  XX(181) = XX(181)
  XX(180) = XX(180)-JVS(2360)*XX(181)
  XX(179) = XX(179)-JVS(2326)*XX(180)-JVS(2359)*XX(181)
  XX(178) = XX(178)-JVS(2275)*XX(179)-JVS(2325)*XX(180)-JVS(2358)*XX(181)
  XX(177) = XX(177)-JVS(2186)*XX(178)-JVS(2274)*XX(179)-JVS(2324)*XX(180)-JVS(2357)*XX(181)
  XX(176) = XX(176)-JVS(2152)*XX(177)-JVS(2185)*XX(178)-JVS(2273)*XX(179)-JVS(2323)*XX(180)-JVS(2356)*XX(181)
  XX(175) = XX(175)-JVS(2108)*XX(176)-JVS(2151)*XX(177)-JVS(2184)*XX(178)-JVS(2272)*XX(179)-JVS(2322)*XX(180)-JVS(2355)&
              &*XX(181)
  XX(174) = XX(174)-JVS(2065)*XX(175)-JVS(2107)*XX(176)-JVS(2150)*XX(177)-JVS(2183)*XX(178)-JVS(2271)*XX(179)-JVS(2321)&
              &*XX(180)-JVS(2354)*XX(181)
  XX(173) = XX(173)-JVS(1999)*XX(174)-JVS(2064)*XX(175)-JVS(2106)*XX(176)-JVS(2149)*XX(177)-JVS(2182)*XX(178)-JVS(2270)&
              &*XX(179)-JVS(2320)*XX(180)-JVS(2353)*XX(181)
  XX(172) = XX(172)-JVS(1938)*XX(173)-JVS(1998)*XX(174)-JVS(2063)*XX(175)-JVS(2105)*XX(176)-JVS(2148)*XX(177)-JVS(2181)&
              &*XX(178)-JVS(2269)*XX(179)-JVS(2319)*XX(180)-JVS(2352)*XX(181)
  XX(171) = XX(171)-JVS(1871)*XX(172)-JVS(1937)*XX(173)-JVS(1997)*XX(174)-JVS(2062)*XX(175)-JVS(2104)*XX(176)-JVS(2147)&
              &*XX(177)-JVS(2180)*XX(178)-JVS(2268)*XX(179)-JVS(2318)*XX(180)-JVS(2351)*XX(181)
  XX(170) = XX(170)-JVS(1839)*XX(171)-JVS(1870)*XX(172)-JVS(1936)*XX(173)-JVS(1996)*XX(174)-JVS(2061)*XX(175)-JVS(2103)&
              &*XX(176)-JVS(2146)*XX(177)-JVS(2179)*XX(178)-JVS(2267)*XX(179)-JVS(2317)*XX(180)-JVS(2350)*XX(181)
  XX(169) = XX(169)-JVS(1788)*XX(170)-JVS(1838)*XX(171)-JVS(1869)*XX(172)-JVS(1935)*XX(173)-JVS(1995)*XX(174)-JVS(2060)&
              &*XX(175)-JVS(2102)*XX(176)-JVS(2145)*XX(177)-JVS(2178)*XX(178)-JVS(2266)*XX(179)-JVS(2316)*XX(180)-JVS(2349)&
              &*XX(181)
  XX(168) = XX(168)-JVS(1659)*XX(169)-JVS(1787)*XX(170)-JVS(1837)*XX(171)-JVS(1868)*XX(172)-JVS(1934)*XX(173)-JVS(1994)&
              &*XX(174)-JVS(2059)*XX(175)-JVS(2101)*XX(176)-JVS(2144)*XX(177)-JVS(2177)*XX(178)-JVS(2265)*XX(179)-JVS(2315)&
              &*XX(180)-JVS(2348)*XX(181)
  XX(167) = XX(167)-JVS(1570)*XX(168)-JVS(1658)*XX(169)-JVS(1786)*XX(170)-JVS(1836)*XX(171)-JVS(1867)*XX(172)-JVS(1933)&
              &*XX(173)-JVS(1993)*XX(174)-JVS(2058)*XX(175)-JVS(2100)*XX(176)-JVS(2143)*XX(177)-JVS(2176)*XX(178)-JVS(2264)&
              &*XX(179)-JVS(2314)*XX(180)-JVS(2347)*XX(181)
  XX(166) = XX(166)-JVS(1532)*XX(167)-JVS(1569)*XX(168)-JVS(1657)*XX(169)-JVS(1785)*XX(170)-JVS(1835)*XX(171)-JVS(1866)&
              &*XX(172)-JVS(1932)*XX(173)-JVS(1992)*XX(174)-JVS(2057)*XX(175)-JVS(2099)*XX(176)-JVS(2142)*XX(177)-JVS(2263)&
              &*XX(179)-JVS(2313)*XX(180)-JVS(2346)*XX(181)
  XX(165) = XX(165)-JVS(1470)*XX(166)-JVS(1568)*XX(168)-JVS(1656)*XX(169)-JVS(1784)*XX(170)-JVS(1834)*XX(171)-JVS(1865)&
              &*XX(172)-JVS(1991)*XX(174)-JVS(2056)*XX(175)-JVS(2098)*XX(176)-JVS(2262)*XX(179)-JVS(2312)*XX(180)-JVS(2345)&
              &*XX(181)
  XX(164) = XX(164)-JVS(1408)*XX(165)-JVS(1469)*XX(166)-JVS(1531)*XX(167)-JVS(1567)*XX(168)-JVS(1655)*XX(169)-JVS(1783)&
              &*XX(170)-JVS(1833)*XX(171)-JVS(1864)*XX(172)-JVS(1931)*XX(173)-JVS(1990)*XX(174)-JVS(2055)*XX(175)-JVS(2097)&
              &*XX(176)-JVS(2141)*XX(177)-JVS(2261)*XX(179)-JVS(2311)*XX(180)-JVS(2344)*XX(181)
  XX(163) = XX(163)-JVS(1338)*XX(164)-JVS(1407)*XX(165)-JVS(1468)*XX(166)-JVS(1530)*XX(167)-JVS(1566)*XX(168)-JVS(1654)&
              &*XX(169)-JVS(1782)*XX(170)-JVS(1832)*XX(171)-JVS(1863)*XX(172)-JVS(1930)*XX(173)-JVS(1989)*XX(174)-JVS(2054)&
              &*XX(175)-JVS(2096)*XX(176)-JVS(2140)*XX(177)-JVS(2260)*XX(179)-JVS(2310)*XX(180)-JVS(2343)*XX(181)
  XX(162) = XX(162)-JVS(1337)*XX(164)-JVS(1406)*XX(165)-JVS(1467)*XX(166)-JVS(1529)*XX(167)-JVS(1565)*XX(168)-JVS(1653)&
              &*XX(169)-JVS(1781)*XX(170)-JVS(1831)*XX(171)-JVS(1862)*XX(172)-JVS(1988)*XX(174)-JVS(2053)*XX(175)-JVS(2095)&
              &*XX(176)-JVS(2139)*XX(177)-JVS(2259)*XX(179)-JVS(2309)*XX(180)-JVS(2342)*XX(181)
  XX(161) = XX(161)-JVS(1257)*XX(162)-JVS(1284)*XX(163)-JVS(1336)*XX(164)-JVS(1405)*XX(165)-JVS(1466)*XX(166)-JVS(1528)&
              &*XX(167)-JVS(1564)*XX(168)-JVS(1652)*XX(169)-JVS(1780)*XX(170)-JVS(1830)*XX(171)-JVS(1861)*XX(172)-JVS(1929)&
              &*XX(173)-JVS(1987)*XX(174)-JVS(2052)*XX(175)-JVS(2094)*XX(176)-JVS(2258)*XX(179)-JVS(2308)*XX(180)-JVS(2341)&
              &*XX(181)
  XX(160) = XX(160)-JVS(1256)*XX(162)-JVS(1335)*XX(164)-JVS(1404)*XX(165)-JVS(1465)*XX(166)-JVS(1527)*XX(167)-JVS(1563)&
              &*XX(168)-JVS(1651)*XX(169)-JVS(1779)*XX(170)-JVS(1860)*XX(172)-JVS(1928)*XX(173)-JVS(1986)*XX(174)-JVS(2051)&
              &*XX(175)-JVS(2093)*XX(176)-JVS(2257)*XX(179)
  XX(159) = XX(159)-JVS(1206)*XX(160)-JVS(1255)*XX(162)-JVS(1283)*XX(163)-JVS(1334)*XX(164)-JVS(1403)*XX(165)-JVS(1464)&
              &*XX(166)-JVS(1526)*XX(167)-JVS(1562)*XX(168)-JVS(1650)*XX(169)-JVS(1778)*XX(170)-JVS(1829)*XX(171)-JVS(1927)&
              &*XX(173)-JVS(1985)*XX(174)-JVS(2050)*XX(175)-JVS(2138)*XX(177)-JVS(2256)*XX(179)-JVS(2307)*XX(180)-JVS(2340)&
              &*XX(181)
  XX(158) = XX(158)-JVS(1649)*XX(169)-JVS(1777)*XX(170)-JVS(1828)*XX(171)-JVS(1859)*XX(172)-JVS(1926)*XX(173)-JVS(1984)&
              &*XX(174)-JVS(2049)*XX(175)-JVS(2092)*XX(176)-JVS(2137)*XX(177)-JVS(2175)*XX(178)-JVS(2255)*XX(179)-JVS(2306)&
              &*XX(180)-JVS(2339)*XX(181)
  XX(157) = XX(157)-JVS(1254)*XX(162)-JVS(1333)*XX(164)-JVS(1402)*XX(165)-JVS(1463)*XX(166)-JVS(1525)*XX(167)-JVS(1561)&
              &*XX(168)-JVS(1648)*XX(169)-JVS(1776)*XX(170)-JVS(1925)*XX(173)-JVS(1983)*XX(174)-JVS(2048)*XX(175)-JVS(2254)&
              &*XX(179)
  XX(156) = XX(156)-JVS(1131)*XX(157)-JVS(1205)*XX(160)-JVS(1253)*XX(162)-JVS(1332)*XX(164)-JVS(1401)*XX(165)-JVS(1462)&
              &*XX(166)-JVS(1524)*XX(167)-JVS(1647)*XX(169)-JVS(1775)*XX(170)-JVS(1858)*XX(172)-JVS(1924)*XX(173)-JVS(1982)&
              &*XX(174)-JVS(2047)*XX(175)-JVS(2091)*XX(176)-JVS(2253)*XX(179)
  XX(155) = XX(155)-JVS(1088)*XX(156)-JVS(1130)*XX(157)-JVS(1204)*XX(160)-JVS(1252)*XX(162)-JVS(1331)*XX(164)-JVS(1400)&
              &*XX(165)-JVS(1461)*XX(166)-JVS(1523)*XX(167)-JVS(1646)*XX(169)-JVS(1774)*XX(170)-JVS(1857)*XX(172)-JVS(1923)&
              &*XX(173)-JVS(1981)*XX(174)-JVS(2046)*XX(175)-JVS(2090)*XX(176)-JVS(2252)*XX(179)
  XX(154) = XX(154)-JVS(1065)*XX(155)-JVS(1087)*XX(156)-JVS(1129)*XX(157)-JVS(1203)*XX(160)-JVS(1251)*XX(162)-JVS(1330)&
              &*XX(164)-JVS(1399)*XX(165)-JVS(1460)*XX(166)-JVS(1522)*XX(167)-JVS(1645)*XX(169)-JVS(1773)*XX(170)-JVS(1922)&
              &*XX(173)-JVS(1980)*XX(174)-JVS(2045)*XX(175)-JVS(2251)*XX(179)
  XX(153) = XX(153)-JVS(1046)*XX(154)-JVS(1064)*XX(155)-JVS(1086)*XX(156)-JVS(1128)*XX(157)-JVS(1250)*XX(162)-JVS(1329)&
              &*XX(164)-JVS(1398)*XX(165)-JVS(1459)*XX(166)-JVS(1521)*XX(167)-JVS(1644)*XX(169)-JVS(1772)*XX(170)-JVS(1921)&
              &*XX(173)-JVS(1979)*XX(174)-JVS(2044)*XX(175)-JVS(2250)*XX(179)
  XX(152) = XX(152)-JVS(1328)*XX(164)-JVS(1458)*XX(166)-JVS(1643)*XX(169)-JVS(1771)*XX(170)-JVS(1978)*XX(174)-JVS(2043)&
              &*XX(175)-JVS(2249)*XX(179)
  XX(151) = XX(151)-JVS(1007)*XX(152)-JVS(1063)*XX(155)-JVS(1127)*XX(157)-JVS(1202)*XX(160)-JVS(1282)*XX(163)-JVS(1327)&
              &*XX(164)-JVS(1397)*XX(165)-JVS(1457)*XX(166)-JVS(1520)*XX(167)-JVS(1560)*XX(168)-JVS(1642)*XX(169)-JVS(1770)&
              &*XX(170)-JVS(1827)*XX(171)-JVS(1920)*XX(173)-JVS(1977)*XX(174)-JVS(2042)*XX(175)-JVS(2248)*XX(179)-JVS(2305)&
              &*XX(180)-JVS(2338)*XX(181)
  XX(150) = XX(150)-JVS(975)*XX(151)-JVS(1006)*XX(152)-JVS(1045)*XX(154)-JVS(1085)*XX(156)-JVS(1126)*XX(157)-JVS(1173)&
              &*XX(159)-JVS(1201)*XX(160)-JVS(1224)*XX(161)-JVS(1249)*XX(162)-JVS(1326)*XX(164)-JVS(1396)*XX(165)-JVS(1456)&
              &*XX(166)-JVS(1519)*XX(167)-JVS(1559)*XX(168)-JVS(1641)*XX(169)-JVS(1769)*XX(170)-JVS(1919)*XX(173)-JVS(1976)&
              &*XX(174)-JVS(2041)*XX(175)-JVS(2247)*XX(179)
  XX(149) = XX(149)-JVS(1005)*XX(152)-JVS(1325)*XX(164)-JVS(1395)*XX(165)-JVS(1455)*XX(166)-JVS(1518)*XX(167)-JVS(1640)&
              &*XX(169)-JVS(1768)*XX(170)
  XX(148) = XX(148)-JVS(936)*XX(149)-JVS(974)*XX(151)-JVS(1004)*XX(152)-JVS(1030)*XX(153)-JVS(1044)*XX(154)-JVS(1062)&
              &*XX(155)-JVS(1125)*XX(157)-JVS(1172)*XX(159)-JVS(1200)*XX(160)-JVS(1223)*XX(161)-JVS(1324)*XX(164)-JVS(1394)&
              &*XX(165)-JVS(1454)*XX(166)-JVS(1517)*XX(167)-JVS(1558)*XX(168)-JVS(1639)*XX(169)-JVS(1767)*XX(170)-JVS(1918)&
              &*XX(173)-JVS(1975)*XX(174)-JVS(2040)*XX(175)-JVS(2246)*XX(179)
  XX(147) = XX(147)-JVS(935)*XX(149)-JVS(1124)*XX(157)-JVS(1199)*XX(160)-JVS(1323)*XX(164)-JVS(1393)*XX(165)-JVS(1453)&
              &*XX(166)-JVS(1516)*XX(167)-JVS(1557)*XX(168)-JVS(1638)*XX(169)-JVS(1766)*XX(170)-JVS(1917)*XX(173)-JVS(1974)&
              &*XX(174)-JVS(2039)*XX(175)-JVS(2245)*XX(179)
  XX(146) = XX(146)-JVS(934)*XX(149)-JVS(1003)*XX(152)-JVS(1123)*XX(157)-JVS(1198)*XX(160)-JVS(1222)*XX(161)-JVS(1281)&
              &*XX(163)-JVS(1322)*XX(164)-JVS(1392)*XX(165)-JVS(1452)*XX(166)-JVS(1515)*XX(167)-JVS(1637)*XX(169)-JVS(1765)&
              &*XX(170)-JVS(1826)*XX(171)-JVS(1916)*XX(173)-JVS(1973)*XX(174)-JVS(2038)*XX(175)-JVS(2244)*XX(179)-JVS(2304)&
              &*XX(180)-JVS(2337)*XX(181)
  XX(145) = XX(145)-JVS(1764)*XX(170)-JVS(1972)*XX(174)-JVS(2037)*XX(175)-JVS(2243)*XX(179)
  XX(144) = XX(144)-JVS(849)*XX(145)-JVS(894)*XX(147)-JVS(933)*XX(149)-JVS(962)*XX(150)-JVS(1084)*XX(156)-JVS(1122)&
              &*XX(157)-JVS(1197)*XX(160)-JVS(1248)*XX(162)-JVS(1321)*XX(164)-JVS(1391)*XX(165)-JVS(1451)*XX(166)-JVS(1514)&
              &*XX(167)-JVS(1556)*XX(168)-JVS(1636)*XX(169)-JVS(1763)*XX(170)-JVS(1915)*XX(173)-JVS(2036)*XX(175)-JVS(2242)&
              &*XX(179)
  XX(143) = XX(143)-JVS(932)*XX(149)-JVS(1002)*XX(152)-JVS(1083)*XX(156)-JVS(1196)*XX(160)-JVS(1320)*XX(164)-JVS(1390)&
              &*XX(165)-JVS(1513)*XX(167)-JVS(1635)*XX(169)-JVS(1762)*XX(170)-JVS(1914)*XX(173)-JVS(1971)*XX(174)-JVS(2241)&
              &*XX(179)
  XX(142) = XX(142)-JVS(1761)*XX(170)-JVS(1825)*XX(171)-JVS(1856)*XX(172)-JVS(1970)*XX(174)-JVS(2089)*XX(176)-JVS(2136)&
              &*XX(177)-JVS(2174)*XX(178)-JVS(2303)*XX(180)-JVS(2336)*XX(181)
  XX(141) = XX(141)-JVS(1061)*XX(155)-JVS(1082)*XX(156)-JVS(1121)*XX(157)-JVS(1247)*XX(162)-JVS(1319)*XX(164)-JVS(1389)&
              &*XX(165)-JVS(1512)*XX(167)-JVS(1634)*XX(169)-JVS(1760)*XX(170)-JVS(1913)*XX(173)-JVS(2240)*XX(179)
  XX(140) = XX(140)-JVS(799)*XX(142)-JVS(848)*XX(145)-JVS(1759)*XX(170)-JVS(1824)*XX(171)-JVS(1855)*XX(172)-JVS(1969)&
              &*XX(174)-JVS(2035)*XX(175)-JVS(2088)*XX(176)-JVS(2135)*XX(177)-JVS(2173)*XX(178)-JVS(2239)*XX(179)-JVS(2302)&
              &*XX(180)-JVS(2335)*XX(181)
  XX(139) = XX(139)-JVS(817)*XX(143)-JVS(1120)*XX(157)-JVS(1318)*XX(164)-JVS(1388)*XX(165)-JVS(1450)*XX(166)-JVS(1511)&
              &*XX(167)-JVS(1633)*XX(169)-JVS(1758)*XX(170)-JVS(1854)*XX(172)-JVS(1912)*XX(173)-JVS(1968)*XX(174)-JVS(2087)&
              &*XX(176)-JVS(2238)*XX(179)
  XX(138) = XX(138)-JVS(847)*XX(145)-JVS(931)*XX(149)-JVS(1001)*XX(152)-JVS(1060)*XX(155)-JVS(1119)*XX(157)-JVS(1195)&
              &*XX(160)-JVS(1317)*XX(164)-JVS(1387)*XX(165)-JVS(1449)*XX(166)-JVS(1510)*XX(167)-JVS(1555)*XX(168)-JVS(1632)&
              &*XX(169)-JVS(1757)*XX(170)-JVS(1911)*XX(173)-JVS(2034)*XX(175)-JVS(2237)*XX(179)
  XX(137) = XX(137)-JVS(846)*XX(145)-JVS(1386)*XX(165)-JVS(1448)*XX(166)-JVS(1631)*XX(169)-JVS(1756)*XX(170)-JVS(2033)&
              &*XX(175)
  XX(136) = XX(136)-JVS(1246)*XX(162)-JVS(1316)*XX(164)-JVS(1385)*XX(165)-JVS(1509)*XX(167)-JVS(1554)*XX(168)-JVS(1630)&
              &*XX(169)-JVS(1755)*XX(170)-JVS(1910)*XX(173)-JVS(2236)*XX(179)
  XX(135) = XX(135)-JVS(816)*XX(143)-JVS(1000)*XX(152)-JVS(1081)*XX(156)-JVS(1118)*XX(157)-JVS(1194)*XX(160)-JVS(1245)&
              &*XX(162)-JVS(1315)*XX(164)-JVS(1384)*XX(165)-JVS(1508)*XX(167)-JVS(1629)*XX(169)-JVS(1754)*XX(170)-JVS(1909)&
              &*XX(173)-JVS(1967)*XX(174)-JVS(2235)*XX(179)
  XX(134) = XX(134)-JVS(1244)*XX(162)-JVS(1314)*XX(164)-JVS(1383)*XX(165)-JVS(1507)*XX(167)-JVS(1628)*XX(169)-JVS(1753)&
              &*XX(170)-JVS(1908)*XX(173)-JVS(2234)*XX(179)
  XX(133) = XX(133)-JVS(734)*XX(137)-JVS(999)*XX(152)-JVS(1117)*XX(157)-JVS(1193)*XX(160)-JVS(1313)*XX(164)-JVS(1382)&
              &*XX(165)-JVS(1506)*XX(167)-JVS(1627)*XX(169)-JVS(1752)*XX(170)-JVS(1907)*XX(173)-JVS(2032)*XX(175)-JVS(2233)&
              &*XX(179)
  XX(132) = XX(132)-JVS(930)*XX(149)-JVS(998)*XX(152)-JVS(1116)*XX(157)-JVS(1192)*XX(160)-JVS(1312)*XX(164)-JVS(1381)&
              &*XX(165)-JVS(1447)*XX(166)-JVS(1505)*XX(167)-JVS(1626)*XX(169)-JVS(1751)*XX(170)-JVS(1906)*XX(173)-JVS(2031)&
              &*XX(175)-JVS(2232)*XX(179)
  XX(131) = XX(131)-JVS(997)*XX(152)-JVS(1115)*XX(157)-JVS(1243)*XX(162)-JVS(1311)*XX(164)-JVS(1380)*XX(165)-JVS(1446)&
              &*XX(166)-JVS(1504)*XX(167)-JVS(1625)*XX(169)-JVS(1750)*XX(170)-JVS(1905)*XX(173)-JVS(2231)*XX(179)
  XX(130) = XX(130)-JVS(782)*XX(141)-JVS(996)*XX(152)-JVS(1029)*XX(153)-JVS(1043)*XX(154)-JVS(1080)*XX(156)-JVS(1114)&
              &*XX(157)-JVS(1310)*XX(164)-JVS(1379)*XX(165)-JVS(1445)*XX(166)-JVS(1503)*XX(167)-JVS(1624)*XX(169)-JVS(1749)&
              &*XX(170)-JVS(1904)*XX(173)-JVS(2230)*XX(179)
  XX(129) = XX(129)-JVS(714)*XX(136)-JVS(893)*XX(147)-JVS(929)*XX(149)-JVS(1079)*XX(156)-JVS(1242)*XX(162)-JVS(1309)&
              &*XX(164)-JVS(1378)*XX(165)-JVS(1444)*XX(166)-JVS(1553)*XX(168)-JVS(1623)*XX(169)-JVS(1748)*XX(170)-JVS(1903)&
              &*XX(173)-JVS(2030)*XX(175)-JVS(2229)*XX(179)
  XX(128) = XX(128)-JVS(1622)*XX(169)-JVS(1747)*XX(170)-JVS(1823)*XX(171)-JVS(1966)*XX(174)-JVS(2301)*XX(180)-JVS(2334)&
              &*XX(181)
  XX(127) = XX(127)-JVS(928)*XX(149)-JVS(1113)*XX(157)-JVS(1241)*XX(162)-JVS(1308)*XX(164)-JVS(1377)*XX(165)-JVS(1502)&
              &*XX(167)-JVS(1621)*XX(169)-JVS(1746)*XX(170)-JVS(1902)*XX(173)-JVS(2228)*XX(179)
  XX(126) = XX(126)-JVS(927)*XX(149)-JVS(995)*XX(152)-JVS(1376)*XX(165)-JVS(1443)*XX(166)-JVS(1620)*XX(169)-JVS(1745)&
              &*XX(170)-JVS(1901)*XX(173)-JVS(2029)*XX(175)-JVS(2227)*XX(179)
  XX(125) = XX(125)-JVS(815)*XX(143)-JVS(1307)*XX(164)-JVS(1442)*XX(166)-JVS(1501)*XX(167)-JVS(1744)*XX(170)-JVS(1853)&
              &*XX(172)-JVS(1965)*XX(174)-JVS(2086)*XX(176)
  XX(124) = XX(124)-JVS(733)*XX(137)-JVS(926)*XX(149)-JVS(973)*XX(151)-JVS(994)*XX(152)-JVS(1042)*XX(154)-JVS(1375)&
              &*XX(165)-JVS(1441)*XX(166)-JVS(1500)*XX(167)-JVS(1552)*XX(168)-JVS(1619)*XX(169)-JVS(1743)*XX(170)-JVS(2226)&
              &*XX(179)
  XX(123) = XX(123)-JVS(1374)*XX(165)-JVS(1499)*XX(167)-JVS(1551)*XX(168)-JVS(1618)*XX(169)-JVS(1742)*XX(170)-JVS(1822)&
              &*XX(171)-JVS(1964)*XX(174)-JVS(2134)*XX(177)-JVS(2300)*XX(180)-JVS(2333)*XX(181)
  XX(122) = XX(122)-JVS(845)*XX(145)-JVS(1373)*XX(165)-JVS(1440)*XX(166)-JVS(1617)*XX(169)-JVS(1741)*XX(170)-JVS(2028)&
              &*XX(175)
  XX(121) = XX(121)-JVS(844)*XX(145)-JVS(925)*XX(149)-JVS(1112)*XX(157)-JVS(1191)*XX(160)-JVS(1306)*XX(164)-JVS(1372)&
              &*XX(165)-JVS(1498)*XX(167)-JVS(1616)*XX(169)-JVS(1740)*XX(170)-JVS(1900)*XX(173)-JVS(2225)*XX(179)
  XX(120) = XX(120)-JVS(1111)*XX(157)-JVS(1305)*XX(164)-JVS(1371)*XX(165)-JVS(1497)*XX(167)-JVS(1615)*XX(169)-JVS(1739)&
              &*XX(170)-JVS(1899)*XX(173)-JVS(2224)*XX(179)
  XX(119) = XX(119)-JVS(1154)*XX(158)-JVS(1738)*XX(170)-JVS(1821)*XX(171)-JVS(1963)*XX(174)-JVS(2085)*XX(176)-JVS(2299)&
              &*XX(180)-JVS(2332)*XX(181)
  XX(118) = XX(118)-JVS(560)*XX(122)-JVS(961)*XX(150)-JVS(1078)*XX(156)-JVS(1110)*XX(157)-JVS(1190)*XX(160)-JVS(1370)&
              &*XX(165)-JVS(1496)*XX(167)-JVS(1614)*XX(169)-JVS(1737)*XX(170)-JVS(1898)*XX(173)-JVS(2027)*XX(175)-JVS(2223)&
              &*XX(179)
  XX(117) = XX(117)-JVS(573)*XX(123)-JVS(611)*XX(127)-JVS(628)*XX(128)-JVS(659)*XX(131)-JVS(1240)*XX(162)-JVS(1280)&
              &*XX(163)-JVS(1369)*XX(165)-JVS(1439)*XX(166)-JVS(1495)*XX(167)-JVS(1550)*XX(168)-JVS(1613)*XX(169)-JVS(1736)&
              &*XX(170)-JVS(1897)*XX(173)-JVS(2026)*XX(175)-JVS(2222)*XX(179)
  XX(116) = XX(116)-JVS(627)*XX(128)-JVS(993)*XX(152)-JVS(1279)*XX(163)-JVS(1304)*XX(164)-JVS(1438)*XX(166)-JVS(1494)&
              &*XX(167)-JVS(1735)*XX(170)-JVS(1896)*XX(173)-JVS(2025)*XX(175)-JVS(2221)*XX(179)
  XX(115) = XX(115)-JVS(992)*XX(152)-JVS(1368)*XX(165)-JVS(1437)*XX(166)-JVS(1493)*XX(167)-JVS(1734)*XX(170)-JVS(2220)&
              &*XX(179)
  XX(114) = XX(114)-JVS(514)*XX(117)-JVS(626)*XX(128)-JVS(679)*XX(133)-JVS(882)*XX(146)-JVS(907)*XX(148)-JVS(960)&
              &*XX(150)-JVS(1171)*XX(159)-JVS(1221)*XX(161)-JVS(1278)*XX(163)-JVS(1303)*XX(164)-JVS(1367)*XX(165)-JVS(1436)&
              &*XX(166)-JVS(1492)*XX(167)-JVS(1549)*XX(168)-JVS(1612)*XX(169)-JVS(1733)*XX(170)-JVS(1895)*XX(173)-JVS(2024)&
              &*XX(175)-JVS(2219)*XX(179)
  XX(113) = XX(113)-JVS(625)*XX(128)-JVS(991)*XX(152)-JVS(1277)*XX(163)-JVS(1435)*XX(166)-JVS(1732)*XX(170)-JVS(1894)&
              &*XX(173)-JVS(2023)*XX(175)-JVS(2218)*XX(179)
  XX(112) = XX(112)-JVS(624)*XX(128)-JVS(1276)*XX(163)-JVS(1366)*XX(165)-JVS(1731)*XX(170)-JVS(1893)*XX(173)-JVS(2022)&
              &*XX(175)-JVS(2217)*XX(179)
  XX(111) = XX(111)-JVS(559)*XX(122)-JVS(959)*XX(150)-JVS(1077)*XX(156)-JVS(1109)*XX(157)-JVS(1189)*XX(160)-JVS(1365)&
              &*XX(165)-JVS(1491)*XX(167)-JVS(1611)*XX(169)-JVS(1730)*XX(170)-JVS(1892)*XX(173)-JVS(2216)*XX(179)
  XX(110) = XX(110)-JVS(798)*XX(142)-JVS(1729)*XX(170)-JVS(1820)*XX(171)-JVS(2133)*XX(177)-JVS(2172)*XX(178)-JVS(2298)&
              &*XX(180)
  XX(109) = XX(109)-JVS(623)*XX(128)-JVS(732)*XX(137)-JVS(924)*XX(149)-JVS(1275)*XX(163)-JVS(1434)*XX(166)-JVS(1728)&
              &*XX(170)-JVS(1891)*XX(173)-JVS(2021)*XX(175)-JVS(2215)*XX(179)
  XX(108) = XX(108)-JVS(1548)*XX(168)-JVS(1610)*XX(169)-JVS(1727)*XX(170)-JVS(1819)*XX(171)-JVS(1962)*XX(174)
  XX(107) = XX(107)-JVS(527)*XX(119)-JVS(843)*XX(145)-JVS(1153)*XX(158)-JVS(1726)*XX(170)-JVS(1961)*XX(174)-JVS(2020)&
              &*XX(175)-JVS(2084)*XX(176)-JVS(2214)*XX(179)-JVS(2297)*XX(180)-JVS(2331)*XX(181)
  XX(106) = XX(106)-JVS(731)*XX(137)-JVS(990)*XX(152)-JVS(1302)*XX(164)-JVS(1364)*XX(165)-JVS(1725)*XX(170)-JVS(2019)&
              &*XX(175)-JVS(2213)*XX(179)
  XX(105) = XX(105)-JVS(622)*XX(128)-JVS(1239)*XX(162)-JVS(1274)*XX(163)-JVS(1433)*XX(166)-JVS(1724)*XX(170)-JVS(1890)&
              &*XX(173)-JVS(2018)*XX(175)-JVS(2212)*XX(179)
  XX(104) = XX(104)-JVS(621)*XX(128)-JVS(1170)*XX(159)-JVS(1273)*XX(163)-JVS(1432)*XX(166)-JVS(1723)*XX(170)-JVS(1889)&
              &*XX(173)-JVS(2017)*XX(175)-JVS(2211)*XX(179)
  XX(103) = XX(103)-JVS(892)*XX(147)-JVS(923)*XX(149)-JVS(1301)*XX(164)-JVS(1363)*XX(165)-JVS(1431)*XX(166)-JVS(1547)&
              &*XX(168)-JVS(1722)*XX(170)-JVS(2016)*XX(175)-JVS(2210)*XX(179)
  XX(102) = XX(102)-JVS(558)*XX(122)-JVS(730)*XX(137)-JVS(842)*XX(145)-JVS(922)*XX(149)-JVS(989)*XX(152)-JVS(1059)&
              &*XX(155)-JVS(1108)*XX(157)-JVS(1609)*XX(169)-JVS(1721)*XX(170)-JVS(1888)*XX(173)-JVS(2209)*XX(179)
  XX(101) = XX(101)-JVS(1107)*XX(157)-JVS(1608)*XX(169)-JVS(1720)*XX(170)
  XX(100) = XX(100)-JVS(841)*XX(145)-JVS(1058)*XX(155)-JVS(1106)*XX(157)-JVS(1607)*XX(169)-JVS(1719)*XX(170)-JVS(1887)&
              &*XX(173)-JVS(2208)*XX(179)
  XX(99) = XX(99)-JVS(921)*XX(149)-JVS(988)*XX(152)-JVS(1362)*XX(165)-JVS(1606)*XX(169)-JVS(1718)*XX(170)-JVS(1886)&
             &*XX(173)-JVS(2015)*XX(175)-JVS(2207)*XX(179)
  XX(98) = XX(98)-JVS(557)*XX(122)-JVS(729)*XX(137)-JVS(920)*XX(149)-JVS(987)*XX(152)-JVS(1361)*XX(165)-JVS(1430)&
             &*XX(166)-JVS(1605)*XX(169)-JVS(1717)*XX(170)-JVS(1885)*XX(173)-JVS(2206)*XX(179)
  XX(97) = XX(97)-JVS(424)*XX(106)-JVS(600)*XX(126)-JVS(972)*XX(151)-JVS(1028)*XX(153)-JVS(1360)*XX(165)-JVS(1546)&
             &*XX(168)-JVS(1604)*XX(169)-JVS(1716)*XX(170)-JVS(2205)*XX(179)
  XX(96) = XX(96)-JVS(781)*XX(141)-JVS(1027)*XX(153)-JVS(1041)*XX(154)-JVS(1105)*XX(157)-JVS(1603)*XX(169)-JVS(1715)&
             &*XX(170)-JVS(2204)*XX(179)
  XX(95) = XX(95)-JVS(958)*XX(150)-JVS(1076)*XX(156)-JVS(1104)*XX(157)-JVS(1188)*XX(160)-JVS(1602)*XX(169)-JVS(1714)&
             &*XX(170)-JVS(2203)*XX(179)
  XX(94) = XX(94)-JVS(797)*XX(142)-JVS(840)*XX(145)-JVS(1713)*XX(170)-JVS(1960)*XX(174)-JVS(2014)*XX(175)-JVS(2202)&
             &*XX(179)-JVS(2296)*XX(180)-JVS(2330)*XX(181)
  XX(93) = XX(93)-JVS(376)*XX(100)-JVS(1187)*XX(160)-JVS(1545)*XX(168)-JVS(1601)*XX(169)-JVS(1712)*XX(170)
  XX(92) = XX(92)-JVS(919)*XX(149)-JVS(1186)*XX(160)-JVS(1429)*XX(166)-JVS(1600)*XX(169)-JVS(1711)*XX(170)
  XX(91) = XX(91)-JVS(327)*XX(92)-JVS(728)*XX(137)-JVS(753)*XX(138)-JVS(918)*XX(149)-JVS(986)*XX(152)-JVS(1428)*XX(166)&
             &-JVS(1599)*XX(169)-JVS(1710)*XX(170)
  XX(90) = XX(90)-JVS(678)*XX(133)-JVS(727)*XX(137)-JVS(985)*XX(152)-JVS(1185)*XX(160)-JVS(1300)*XX(164)-JVS(1359)&
             &*XX(165)-JVS(1598)*XX(169)-JVS(1709)*XX(170)
  XX(89) = XX(89)-JVS(690)*XX(134)-JVS(839)*XX(145)-JVS(1427)*XX(166)-JVS(1708)*XX(170)-JVS(1852)*XX(172)-JVS(1959)&
             &*XX(174)-JVS(2013)*XX(175)-JVS(2083)*XX(176)
  XX(88) = XX(88)-JVS(669)*XX(132)-JVS(917)*XX(149)-JVS(1358)*XX(165)-JVS(1426)*XX(166)-JVS(1597)*XX(169)-JVS(1707)&
             &*XX(170)
  XX(87) = XX(87)-JVS(363)*XX(98)-JVS(906)*XX(148)-JVS(971)*XX(151)-JVS(1169)*XX(159)-JVS(1220)*XX(161)-JVS(1357)&
             &*XX(165)-JVS(1596)*XX(169)-JVS(1706)*XX(170)
  XX(86) = XX(86)-JVS(814)*XX(143)-JVS(984)*XX(152)-JVS(1299)*XX(164)-JVS(1356)*XX(165)-JVS(1705)*XX(170)-JVS(1958)&
             &*XX(174)
  XX(85) = XX(85)-JVS(1057)*XX(155)-JVS(1103)*XX(157)-JVS(1595)*XX(169)-JVS(1704)*XX(170)
  XX(84) = XX(84)-JVS(610)*XX(127)-JVS(916)*XX(149)-JVS(1238)*XX(162)-JVS(1355)*XX(165)-JVS(1594)*XX(169)-JVS(1703)&
             &*XX(170)
  XX(83) = XX(83)-JVS(495)*XX(115)-JVS(658)*XX(131)-JVS(1102)*XX(157)-JVS(1593)*XX(169)-JVS(1702)*XX(170)-JVS(2201)&
             &*XX(179)
  XX(82) = XX(82)-JVS(1354)*XX(165)-JVS(1701)*XX(170)-JVS(2200)*XX(179)
  XX(81) = XX(81)-JVS(526)*XX(119)-JVS(1700)*XX(170)-JVS(2082)*XX(176)
  XX(80) = XX(80)-JVS(1272)*XX(163)-JVS(1699)*XX(170)
  XX(79) = XX(79)-JVS(713)*XX(136)-JVS(1237)*XX(162)-JVS(1592)*XX(169)-JVS(1698)*XX(170)
  XX(78) = XX(78)-JVS(2081)*XX(176)-JVS(2295)*XX(180)
  XX(77) = XX(77)-JVS(1591)*XX(169)-JVS(1697)*XX(170)-JVS(1957)*XX(174)-JVS(2012)*XX(175)-JVS(2199)*XX(179)
  XX(76) = XX(76)-JVS(1353)*XX(165)-JVS(1490)*XX(167)-JVS(1590)*XX(169)-JVS(1696)*XX(170)-JVS(1956)*XX(174)
  XX(75) = XX(75)-JVS(457)*XX(110)-JVS(2171)*XX(178)-JVS(2294)*XX(180)
  XX(74) = XX(74)-JVS(549)*XX(121)-JVS(891)*XX(147)-JVS(1298)*XX(164)-JVS(1352)*XX(165)-JVS(1695)*XX(170)
  XX(73) = XX(73)-JVS(1425)*XX(166)-JVS(1489)*XX(167)-JVS(1589)*XX(169)-JVS(1694)*XX(170)-JVS(1955)*XX(174)-JVS(2293)&
             &*XX(180)-JVS(2329)*XX(181)
  XX(72) = XX(72)-JVS(1152)*XX(158)-JVS(1488)*XX(167)-JVS(1588)*XX(169)-JVS(1693)*XX(170)-JVS(1954)*XX(174)-JVS(2080)&
             &*XX(176)-JVS(2132)*XX(177)
  XX(71) = XX(71)-JVS(1692)*XX(170)-JVS(1884)*XX(173)-JVS(1953)*XX(174)-JVS(2198)*XX(179)
  XX(70) = XX(70)-JVS(689)*XX(134)-JVS(1236)*XX(162)-JVS(1587)*XX(169)-JVS(1691)*XX(170)
  XX(69) = XX(69)-JVS(539)*XX(120)-JVS(762)*XX(139)-JVS(1424)*XX(166)-JVS(1690)*XX(170)-JVS(1851)*XX(172)-JVS(2079)&
             &*XX(176)
  XX(68) = XX(68)-JVS(1689)*XX(170)-JVS(1818)*XX(171)-JVS(1952)*XX(174)-JVS(2131)*XX(177)-JVS(2170)*XX(178)-JVS(2292)&
             &*XX(180)
  XX(67) = XX(67)-JVS(1688)*XX(170)-JVS(1817)*XX(171)-JVS(1951)*XX(174)-JVS(2130)*XX(177)-JVS(2169)*XX(178)-JVS(2291)&
             &*XX(180)
  XX(66) = XX(66)-JVS(1687)*XX(170)-JVS(1816)*XX(171)-JVS(1950)*XX(174)-JVS(2129)*XX(177)-JVS(2168)*XX(178)-JVS(2290)&
             &*XX(180)
  XX(65) = XX(65)-JVS(1686)*XX(170)-JVS(1815)*XX(171)-JVS(1949)*XX(174)-JVS(2128)*XX(177)-JVS(2167)*XX(178)-JVS(2289)&
             &*XX(180)
  XX(64) = XX(64)-JVS(796)*XX(142)-JVS(1685)*XX(170)-JVS(2197)*XX(179)-JVS(2288)*XX(180)
  XX(63) = XX(63)-JVS(795)*XX(142)-JVS(1684)*XX(170)-JVS(1814)*XX(171)-JVS(2166)*XX(178)
  XX(62) = XX(62)-JVS(838)*XX(145)-JVS(1271)*XX(163)-JVS(1351)*XX(165)-JVS(1487)*XX(167)-JVS(1683)*XX(170)-JVS(2011)&
             &*XX(175)
  XX(61) = XX(61)-JVS(589)*XX(125)-JVS(761)*XX(139)-JVS(1586)*XX(169)-JVS(1682)*XX(170)
  XX(60) = XX(60)-JVS(538)*XX(120)-JVS(1101)*XX(157)-JVS(1585)*XX(169)-JVS(1681)*XX(170)
  XX(59) = XX(59)-JVS(234)*XX(75)-JVS(794)*XX(142)-JVS(1680)*XX(170)-JVS(2165)*XX(178)-JVS(2287)*XX(180)
  XX(58) = XX(58)-JVS(1350)*XX(165)-JVS(1486)*XX(167)-JVS(1584)*XX(169)-JVS(2010)*XX(175)-JVS(2196)*XX(179)
  XX(57) = XX(57)-JVS(1151)*XX(158)-JVS(1679)*XX(170)-JVS(1813)*XX(171)-JVS(2078)*XX(176)-JVS(2127)*XX(177)
  XX(56) = XX(56)-JVS(1150)*XX(158)-JVS(1678)*XX(170)-JVS(1812)*XX(171)-JVS(2077)*XX(176)-JVS(2126)*XX(177)
  XX(55) = XX(55)-JVS(1297)*XX(164)-JVS(1485)*XX(167)-JVS(1677)*XX(170)
  XX(54) = XX(54)-JVS(837)*XX(145)-JVS(1056)*XX(155)-JVS(1676)*XX(170)-JVS(2009)*XX(175)
  XX(53) = XX(53)-JVS(1811)*XX(171)-JVS(1883)*XX(173)-JVS(2125)*XX(177)-JVS(2195)*XX(179)
  XX(52) = XX(52)-JVS(1270)*XX(163)-JVS(1423)*XX(166)-JVS(1675)*XX(170)-JVS(1810)*XX(171)
  XX(51) = XX(51)-JVS(1296)*XX(164)-JVS(1484)*XX(167)-JVS(2008)*XX(175)-JVS(2194)*XX(179)
  XX(50) = XX(50)-JVS(1149)*XX(158)-JVS(1809)*XX(171)-JVS(2076)*XX(176)-JVS(2124)*XX(177)-JVS(2164)*XX(178)-JVS(2286)&
             &*XX(180)
  XX(49) = XX(49)-JVS(1882)*XX(173)-JVS(2123)*XX(177)
  XX(48) = XX(48)-JVS(1148)*XX(158)-JVS(1808)*XX(171)-JVS(2075)*XX(176)-JVS(2122)*XX(177)
  XX(47) = XX(47)-JVS(1147)*XX(158)-JVS(1807)*XX(171)-JVS(2074)*XX(176)-JVS(2121)*XX(177)
  XX(46) = XX(46)-JVS(1806)*XX(171)-JVS(2120)*XX(177)-JVS(2163)*XX(178)-JVS(2285)*XX(180)
  XX(45) = XX(45)-JVS(1805)*XX(171)-JVS(2119)*XX(177)-JVS(2162)*XX(178)-JVS(2284)*XX(180)
  XX(44) = XX(44)-JVS(1804)*XX(171)-JVS(2118)*XX(177)-JVS(2161)*XX(178)-JVS(2283)*XX(180)
  XX(43) = XX(43)-JVS(1803)*XX(171)-JVS(2117)*XX(177)-JVS(2160)*XX(178)-JVS(2282)*XX(180)
  XX(42) = XX(42)-JVS(1802)*XX(171)-JVS(2116)*XX(177)-JVS(2159)*XX(178)-JVS(2281)*XX(180)
  XX(41) = XX(41)-JVS(1801)*XX(171)-JVS(2115)*XX(177)-JVS(2158)*XX(178)-JVS(2280)*XX(180)
  XX(40) = XX(40)-JVS(369)*XX(99)-JVS(2193)*XX(179)
  XX(39) = XX(39)-JVS(362)*XX(98)-JVS(1674)*XX(170)
  XX(38) = XX(38)-JVS(2073)*XX(176)-JVS(2192)*XX(179)
  XX(37) = XX(37)-JVS(712)*XX(136)-JVS(2191)*XX(179)
  XX(36) = XX(36)-JVS(1673)*XX(170)-JVS(1948)*XX(174)-JVS(2279)*XX(180)
  XX(35) = XX(35)
  XX(34) = XX(34)
  XX(33) = XX(33)
  XX(32) = XX(32)
  XX(31) = XX(31)
  XX(30) = XX(30)
  XX(29) = XX(29)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)
  XX(4) = XX(4)
  XX(3) = XX(3)
  XX(2) = XX(2)
  XX(1) = XX(1)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.
      
!$OMP THREADPRIVATE( Eps, First )

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

